@@ -10,8 +10,6 @@ NeuroImage, vol. 44, no. 3, pp. 947?66, Mar. 2009.
 #
 # License: BSD (3-clause)
 
-print(__doc__)
-
 import numpy as np
 
 import mne
@@ -19,6 +17,8 @@ from mne.datasets import sample
 from mne.inverse_sparse import gamma_map
 from mne.viz import plot_sparse_source_estimates
 
+print(__doc__)
+
 data_path = sample.data_path()
 subjects_dir = data_path + '/subjects'
 fwd_fname = data_path + '/MEG/sample/sample_audvis-meg-eeg-oct-6-fwd.fif'
@@ -35,7 +35,7 @@ evoked.crop(tmin=-50e-3, tmax=300e-3)
 forward = mne.read_forward_solution(fwd_fname, surf_ori=True,
                                     force_fixed=False)
 
-# Read noise covariance matrix and regularize it
+# Read noise noise covariance matrix and regularize it
 cov = mne.read_cov(cov_fname)
 cov = mne.cov.regularize(cov, evoked.info)
 
@@ -50,16 +50,17 @@ stc, residual = gamma_map(evoked, forward, cov, alpha, xyz_same_gamma=True,
 scale_factors = np.max(np.abs(stc.data), axis=1)
 scale_factors = 0.5 * (1 + scale_factors / np.max(scale_factors))
 
-plot_sparse_source_estimates(forward['src'], stc, bgcolor=(1, 1, 1),
+plot_sparse_source_estimates(
+    forward['src'], stc, bgcolor=(1, 1, 1),
     modes=['sphere'], opacity=0.1, scale_factors=(scale_factors, None),
     fig_name="Gamma-MAP")
 
 # Show the evoked response and the residual for gradiometers
 ylim = dict(grad=[-120, 120])
-evoked = mne.pick_types_evoked(evoked, meg='grad', exclude='bads')
+evoked.pick_types(meg='grad', exclude='bads')
 evoked.plot(titles=dict(grad='Evoked Response Gradiometers'), ylim=ylim,
             proj=True)
 
-residual = mne.pick_types_evoked(residual, meg='grad', exclude='bads')
+residual.pick_types(meg='grad', exclude='bads')
 residual.plot(titles=dict(grad='Residuals Gradiometers'), ylim=ylim,
               proj=True)
