@@ -31,8 +31,7 @@ efficient sensor selection in a P300 BCI. In Signal Processing Conference,
 # License: BSD (3-clause)
 
 
-from mne import (io, compute_raw_covariance, read_events, pick_types,
-                 Epochs)
+from mne import (io, compute_raw_covariance, read_events, pick_types, Epochs)
 from mne.datasets import sample
 from mne.preprocessing import Xdawn
 from mne.viz import plot_epochs_image
@@ -76,5 +75,5 @@ xd.fit(epochs)
 # Denoise epochs
 epochs_denoised = xd.apply(epochs)
 
-# Plot image epoch after xdawn
+# Plot image epoch after Xdawn
 plot_epochs_image(epochs_denoised['vis_r'], picks=[230], vmin=-500, vmax=500)
