@@ -70,10 +70,11 @@ with FieldTripClient(host='localhost', port=1972,
     for ii, ev in enumerate(rt_epochs.iter_evoked()):
         print("Just got epoch %d" % (ii + 1))
 
+        ev.pick_types(meg=True, eog=False)
         if ii == 0:
             evoked = ev
         else:
-            evoked += ev
+            evoked = mne.combine_evoked([evoked, ev], weights='nave')
 
         ax[0].cla()
         ax[1].cla()  # clear axis
