@@ -36,19 +36,22 @@ def rescale(data, times, baseline, mode='mean', copy=True, verbose=None):
         Time instants is seconds.
     baseline : tuple or list of length 2, or None
         The time interval to apply rescaling / baseline correction.
-        If None do not apply it. If baseline is (a, b)
-        the interval is between "a (s)" and "b (s)".
-        If a is None the beginning of the data is used
-        and if b is None then b is set to the end of the interval.
-        If baseline is equal ot (None, None) all the time
-        interval is used. If None, no correction is applied.
-    mode : 'logratio' | 'ratio' | 'zscore' | 'mean' | 'percent' | 'zlogratio'
+        If None do not apply it. If baseline is ``(bmin, bmax)``
+        the interval is between ``bmin`` (s) and ``bmax`` (s).
+        If ``bmin is None`` the beginning of the data is used
+        and if ``bmax is None`` then ``bmax`` is set to the end of the
+        interval. If baseline is ``(None, None)`` the entire time
+        interval is used. If baseline is None, no correction is applied.
+    mode : None | 'ratio' | 'zscore' | 'mean' | 'percent' | 'logratio' | 'zlogratio' # noqa
         Do baseline correction with ratio (power is divided by mean
         power during baseline) or zscore (power is divided by standard
         deviation of power during baseline after subtracting the mean,
-        power = [power - mean(power_baseline)] / std(power_baseline)).
-        logratio is the same an mean but in log-scale, zlogratio is the
-        same as zscore but data is rendered in log-scale first.
+        power = [power - mean(power_baseline)] / std(power_baseline)), mean
+        simply subtracts the mean power, percent is the same as applying ratio
+        then mean, logratio is the same as mean but then rendered in log-scale,
+        zlogratio is the same as zscore but data is rendered in log-scale
+        first.
+        If None no baseline correction is applied.
     copy : bool
         Whether to return a new instance or modify in place.
     verbose : bool, str, int, or None
@@ -68,11 +71,22 @@ def rescale(data, times, baseline, mode='mean', copy=True, verbose=None):
     if bmin is None:
         imin = 0
     else:
-        imin = int(np.where(times >= bmin)[0][0])
+        imin = np.where(times >= bmin)[0]
+        if len(imin) == 0:
+            raise ValueError('bmin is too large (%s), it exceeds the largest '
+                             'time value' % (bmin,))
+        imin = int(imin[0])
     if bmax is None:
         imax = len(times)
     else:
-        imax = int(np.where(times <= bmax)[0][-1]) + 1
+        imax = np.where(times <= bmax)[0]
+        if len(imax) == 0:
+            raise ValueError('bmax is too small (%s), it is smaller than the '
+                             'smallest time value' % (bmax,))
+        imax = int(imax[-1]) + 1
+    if imin >= imax:
+        raise ValueError('Bad rescaling slice (%s:%s) from time values %s, %s'
+                         % (imin, imax, bmin, bmax))
 
     # avoid potential "empty slice" warning
     if data.shape[-1] > 0:
