@@ -3,8 +3,9 @@
 #          Eric Larson <larson.eric.d@gmail.com>
 # License: BSD Style.
 
+from functools import partial
+
 from ...utils import verbose
-from ...fixes import partial
 from ..utils import (has_dataset, _data_path, _data_path_doc,
                      _get_version, _version_doc)
 
