@@ -3,6 +3,7 @@
 #          Alexandre Gramfort <alexandre.gramfort@telecom-paristech.fr>
 #          Alexandre Barachant <alexandre.barachant@gmail.com>
 #          Clemens Brunner <clemens.brunner@gmail.com>
+#          Jean-Remi King <jeanremi.king@gmail.com>
 #
 # License: BSD (3-clause)
 
@@ -11,46 +12,54 @@ import copy as cp
 import numpy as np
 from scipy import linalg
 
-from .mixin import TransformerMixin, EstimatorMixin
+from .mixin import TransformerMixin
+from .base import BaseEstimator
 from ..cov import _regularized_covariance
+from ..utils import warn
 
 
-class CSP(TransformerMixin, EstimatorMixin):
+class CSP(TransformerMixin, BaseEstimator):
     """M/EEG signal decomposition using the Common Spatial Patterns (CSP).
 
     This object can be used as a supervised decomposition to estimate
     spatial filters for feature extraction in a 2 class decoding problem.
     CSP in the context of EEG was first described in [1]; a comprehensive
-    tutorial on CSP can be found in [2].
+    tutorial on CSP can be found in [2]. Multiclass solving is implemented
+    from [3].
 
     Parameters
     ----------
-    n_components : int (default 4)
+    n_components : int, defaults to 4
         The number of components to decompose M/EEG signals.
         This number should be set by cross-validation.
-    reg : float | str | None (default None)
+    reg : float | str | None, defaults to None
         if not None, allow regularization for covariance estimation
         if float, shrinkage covariance is used (0 <= shrinkage <= 1).
         if str, optimal shrinkage using Ledoit-Wolf Shrinkage ('ledoit_wolf')
         or Oracle Approximating Shrinkage ('oas').
-    log : bool (default True)
-        If true, apply log to standardize the features.
-        If false, features are just z-scored.
-    cov_est : str (default 'concat')
+    log : None | bool, defaults to None
+        If transform_into == 'average_power' and log is None or True, then
+        applies a log transform to standardize the features, else the features
+        are z-scored. If transform_into == 'csp_space', then log must be None.
+    cov_est : 'concat' | 'epoch', defaults to 'concat'
         If 'concat', covariance matrices are estimated on concatenated epochs
         for each class.
         If 'epoch', covariance matrices are estimated on each epoch separately
         and then averaged over each class.
+    transform_into : {'average_power', 'csp_space'}
+        If 'average_power' then self.transform will return the average power of
+        each spatial filter. If 'csp_space' self.transform will return the data
+        in CSP space. Defaults to 'average_power'.
 
     Attributes
     ----------
-    filters_ : ndarray, shape (n_channels, n_channels)
+    ``filters_`` : ndarray, shape (n_channels, n_channels)
         If fit, the CSP components used to decompose the data, else None.
-    patterns_ : ndarray, shape (n_channels, n_channels)
+    ``patterns_`` : ndarray, shape (n_channels, n_channels)
         If fit, the CSP patterns used to restore M/EEG signals, else None.
-    mean_ : ndarray, shape (n_channels,)
+    ``mean_`` : ndarray, shape (n_components,)
         If fit, the mean squared power for each component.
-    std_ : ndarray, shape (n_channels,)
+    ``std_`` : ndarray, shape (n_components,)
         If fit, the std squared power for each component.
 
     References
@@ -62,40 +71,67 @@ class CSP(TransformerMixin, EstimatorMixin):
         Klaus-Robert Müller. Optimizing Spatial Filters for Robust EEG
         Single-Trial Analysis. IEEE Signal Processing Magazine 25(1), 41-56,
         2008.
+    [3] Grosse-Wentrup, Moritz, and Martin Buss. Multiclass common spatial
+        patterns and information theoretic feature extraction. IEEE
+        Transactions on Biomedical Engineering, Vol 55, no. 8, 2008.
     """
 
-    def __init__(self, n_components=4, reg=None, log=True, cov_est="concat"):
+    def __init__(self, n_components=4, reg=None, log=None, cov_est="concat",
+                 transform_into='average_power'):
         """Init of CSP."""
+        # Init default CSP
+        if not isinstance(n_components, int):
+            raise ValueError('n_components must be an integer.')
         self.n_components = n_components
+
+        # Init default regularization
+        if (
+            (reg is not None) and
+            (reg not in ['oas', 'ledoit_wolf']) and
+            ((not isinstance(reg, (float, int))) or
+             (not ((reg <= 1.) and (reg >= 0.))))
+        ):
+            raise ValueError('reg must be None, "oas", "ledoit_wolf" or a '
+                             'float in between 0. and 1.')
         self.reg = reg
-        self.log = log
+
+        # Init default cov_est
+        if not (cov_est == "concat" or cov_est == "epoch"):
+            raise ValueError("unknown covariance estimation method")
         self.cov_est = cov_est
-        self.filters_ = None
-        self.patterns_ = None
-        self.mean_ = None
-        self.std_ = None
 
-    def get_params(self, deep=True):
-        """Return all parameters (mimics sklearn API).
+        # Init default transform_into
+        if transform_into not in ('average_power', 'csp_space'):
+            raise ValueError('transform_into must be "average_power" or '
+                             '"csp_space".')
+        self.transform_into = transform_into
 
-        Parameters
-        ----------
-        deep: boolean, optional
-            If True, will return the parameters for this estimator and
-            contained subobjects that are estimators.
-        """
-        params = {"n_components": self.n_components,
-                  "reg": self.reg,
-                  "log": self.log}
-        return params
+        # Init default log
+        if transform_into == 'average_power':
+            if log is not None and not isinstance(log, bool):
+                raise ValueError('log must be a boolean if transform_into == '
+                                 '"average_power".')
+        else:
+            if log is not None:
+                raise ValueError('log must be a None if transform_into == '
+                                 '"csp_space".')
+        self.log = log
 
-    def fit(self, epochs_data, y):
+    def _check_Xy(self, X, y=None):
+        """Aux. function to check input data."""
+        if y is not None:
+            if len(X) != len(y) or len(y) < 1:
+                raise ValueError('X and y must have the same length.')
+        if X.ndim < 3:
+            raise ValueError('X must have at least 3 dimensions.')
+
+    def fit(self, X, y, epochs_data=None):
         """Estimate the CSP decomposition on epochs.
 
         Parameters
         ----------
-        epochs_data : ndarray, shape (n_epochs, n_channels, n_times)
-            The data to estimate the CSP on.
+        X : ndarray, shape (n_epochs, n_channels, n_times)
+            The data on which to estimate the CSP.
         y : array, shape (n_epochs,)
             The class for each epoch.
 
@@ -104,55 +140,81 @@ class CSP(TransformerMixin, EstimatorMixin):
         self : instance of CSP
             Returns the modified instance.
         """
-        if not isinstance(epochs_data, np.ndarray):
-            raise ValueError("epochs_data should be of type ndarray (got %s)."
-                             % type(epochs_data))
-        epochs_data = np.atleast_3d(epochs_data)
-        e, c, t = epochs_data.shape
-        # check number of epochs
-        if e != len(y):
-            raise ValueError("n_epochs must be the same for epochs_data and y")
-        classes = np.unique(y)
-        if len(classes) != 2:
-            raise ValueError("More than two different classes in the data.")
-        if not (self.cov_est == "concat" or self.cov_est == "epoch"):
-            raise ValueError("unknown covariance estimation method")
+        X = _check_deprecate(epochs_data, X)
+        if not isinstance(X, np.ndarray):
+            raise ValueError("X should be of type ndarray (got %s)."
+                             % type(X))
+        self._check_Xy(X, y)
+        n_channels = X.shape[1]
 
-        if self.cov_est == "concat":  # concatenate epochs
-            class_1 = np.transpose(epochs_data[y == classes[0]],
-                                   [1, 0, 2]).reshape(c, -1)
-            class_2 = np.transpose(epochs_data[y == classes[1]],
-                                   [1, 0, 2]).reshape(c, -1)
-            cov_1 = _regularized_covariance(class_1, reg=self.reg)
-            cov_2 = _regularized_covariance(class_2, reg=self.reg)
-        elif self.cov_est == "epoch":
-            class_1 = epochs_data[y == classes[0]]
-            class_2 = epochs_data[y == classes[1]]
-            cov_1 = np.zeros((c, c))
-            for t in class_1:
-                cov_1 += _regularized_covariance(t, reg=self.reg)
-            cov_1 /= class_1.shape[0]
-            cov_2 = np.zeros((c, c))
-            for t in class_2:
-                cov_2 += _regularized_covariance(t, reg=self.reg)
-            cov_2 /= class_2.shape[0]
+        self._classes = np.unique(y)
+        n_classes = len(self._classes)
+        if n_classes < 2:
+            raise ValueError("n_classes must be >= 2.")
 
-        # normalize by trace
-        cov_1 /= np.trace(cov_1)
-        cov_2 /= np.trace(cov_2)
+        covs = np.zeros((n_classes, n_channels, n_channels))
+        sample_weights = list()
+        for class_idx, this_class in enumerate(self._classes):
+            if self.cov_est == "concat":  # concatenate epochs
+                class_ = np.transpose(X[y == this_class], [1, 0, 2])
+                class_ = class_.reshape(n_channels, -1)
+                cov = _regularized_covariance(class_, reg=self.reg)
+                weight = sum(y == this_class)
+            elif self.cov_est == "epoch":
+                class_ = X[y == this_class]
+                cov = np.zeros((n_channels, n_channels))
+                for this_X in class_:
+                    cov += _regularized_covariance(this_X, reg=self.reg)
+                cov /= len(class_)
+                weight = len(class_)
 
-        e, w = linalg.eigh(cov_1, cov_1 + cov_2)
-        n_vals = len(e)
-        # Rearrange vectors
-        ind = np.empty(n_vals, dtype=int)
-        ind[::2] = np.arange(n_vals - 1, n_vals // 2 - 1, -1)
-        ind[1::2] = np.arange(0, n_vals // 2)
-        w = w[:, ind]  # first, last, second, second last, third, ...
-        self.filters_ = w.T
-        self.patterns_ = linalg.pinv(w)
+            # normalize by trace and stack
+            covs[class_idx] = cov / np.trace(cov)
+            sample_weights.append(weight)
+
+        if n_classes == 2:
+            eigen_values, eigen_vectors = linalg.eigh(covs[0], covs.sum(0))
+            # sort eigenvectors
+            ix = np.argsort(np.abs(eigen_values - 0.5))[::-1]
+        else:
+            # The multiclass case is adapted from
+            # http://github.com/alexandrebarachant/pyRiemann
+            eigen_vectors, D = _ajd_pham(covs)
+
+            # Here we apply an euclidean mean. See pyRiemann for other metrics
+            mean_cov = np.average(covs, axis=0, weights=sample_weights)
+            eigen_vectors = eigen_vectors.T
+
+            # normalize
+            for ii in range(eigen_vectors.shape[1]):
+                tmp = np.dot(np.dot(eigen_vectors[:, ii].T, mean_cov),
+                             eigen_vectors[:, ii])
+                eigen_vectors[:, ii] /= np.sqrt(tmp)
+
+            # class probability
+            class_probas = [np.mean(y == _class) for _class in self._classes]
+
+            # mutual information
+            mutual_info = []
+            for jj in range(eigen_vectors.shape[1]):
+                aa, bb = 0, 0
+                for (cov, prob) in zip(covs, class_probas):
+                    tmp = np.dot(np.dot(eigen_vectors[:, jj].T, cov),
+                                 eigen_vectors[:, jj])
+                    aa += prob * np.log(np.sqrt(tmp))
+                    bb += prob * (tmp ** 2 - 1)
+                mi = - (aa + (3.0 / 16) * (bb ** 2))
+                mutual_info.append(mi)
+            ix = np.argsort(mutual_info)[::-1]
+
+        # sort eigenvectors
+        eigen_vectors = eigen_vectors[:, ix]
+
+        self.filters_ = eigen_vectors.T
+        self.patterns_ = linalg.pinv(eigen_vectors)
 
         pick_filters = self.filters_[:self.n_components]
-        X = np.asarray([np.dot(pick_filters, epoch) for epoch in epochs_data])
+        X = np.asarray([np.dot(pick_filters, epoch) for epoch in X])
 
         # compute features (mean band power)
         X = (X ** 2).mean(axis=-1)
@@ -163,38 +225,41 @@ class CSP(TransformerMixin, EstimatorMixin):
 
         return self
 
-    def transform(self, epochs_data, y=None):
+    def transform(self, X, epochs_data=None):
         """Estimate epochs sources given the CSP filters.
 
         Parameters
         ----------
-        epochs_data : array, shape (n_epochs, n_channels, n_times)
+        X : array, shape (n_epochs, n_channels, n_times)
             The data.
-        y : None
-            Not used.
 
         Returns
         -------
-        X : ndarray of shape (n_epochs, n_sources)
-            The CSP features averaged over time.
+        X : ndarray
+            If self.transform_into == 'average_power' then returns the power of
+            CSP features averaged over time and shape (n_epochs, n_sources)
+            If self.transform_into == 'csp_space' then returns the data in CSP
+            space and shape is (n_epochs, n_sources, n_times)
         """
-        if not isinstance(epochs_data, np.ndarray):
-            raise ValueError("epochs_data should be of type ndarray (got %s)."
-                             % type(epochs_data))
+        X = _check_deprecate(epochs_data, X)
+        if not isinstance(X, np.ndarray):
+            raise ValueError("X should be of type ndarray (got %s)." % type(X))
         if self.filters_ is None:
             raise RuntimeError('No filters available. Please first fit CSP '
                                'decomposition.')
 
         pick_filters = self.filters_[:self.n_components]
-        X = np.asarray([np.dot(pick_filters, epoch) for epoch in epochs_data])
+        X = np.asarray([np.dot(pick_filters, epoch) for epoch in X])
 
         # compute features (mean band power)
-        X = (X ** 2).mean(axis=-1)
-        if self.log:
-            X = np.log(X)
-        else:
-            X -= self.mean_
-            X /= self.std_
+        if self.transform_into == 'average_power':
+            X = (X ** 2).mean(axis=-1)
+            log = True if self.log is None else self.log
+            if log:
+                X = np.log(X)
+            else:
+                X -= self.mean_
+                X /= self.std_
         return X
 
     def plot_patterns(self, info, components=None, ch_type=None, layout=None,
@@ -236,9 +301,20 @@ class CSP(TransformerMixin, EstimatorMixin):
             If None, the maximum absolute value is used. If vmin is None,
             but vmax is not, defaults to np.min(data).
             If callable, the output equals vmax(data).
-        cmap : matplotlib colormap
-            Colormap. For magnetometers and eeg defaults to 'RdBu_r', else
-            'Reds'.
+        cmap : matplotlib colormap | (colormap, bool) | 'interactive' | None
+            Colormap to use. If tuple, the first value indicates the colormap
+            to use and the second value is a boolean defining interactivity. In
+            interactive mode the colors are adjustable by clicking and dragging
+            the colorbar with left and right mouse button. Left mouse button
+            moves the scale up and down and right mouse button adjusts the
+            range. Hitting space bar resets the range. Up and down arrows can
+            be used to change the colormap. If None, 'Reds' is used for all
+            positive data, otherwise defaults to 'RdBu_r'. If 'interactive',
+            translates to (None, True). Defaults to 'RdBu_r'.
+
+            .. warning::  Interactive mode works smoothly only for a small
+                amount of topomaps.
+
         sensors : bool | str
             Add markers for sensor locations to the plot. Accepts matplotlib
             plot format string (e.g., 'r+' for red plusses). If True,
@@ -381,9 +457,20 @@ class CSP(TransformerMixin, EstimatorMixin):
             If None, the maximum absolute value is used. If vmin is None,
             but vmax is not, defaults to np.min(data).
             If callable, the output equals vmax(data).
-        cmap : matplotlib colormap
-            Colormap. For magnetometers and eeg defaults to 'RdBu_r', else
-            'Reds'.
+        cmap : matplotlib colormap | (colormap, bool) | 'interactive' | None
+            Colormap to use. If tuple, the first value indicates the colormap
+            to use and the second value is a boolean defining interactivity. In
+            interactive mode the colors are adjustable by clicking and dragging
+            the colorbar with left and right mouse button. Left mouse button
+            moves the scale up and down and right mouse button adjusts the
+            range. Hitting space bar resets the range. Up and down arrows can
+            be used to change the colormap. If None, 'Reds' is used for all
+            positive data, otherwise defaults to 'RdBu_r'. If 'interactive',
+            translates to (None, True). Defaults to 'RdBu_r'.
+
+            .. warning::  Interactive mode works smoothly only for a small
+                amount of topomaps.
+
         sensors : bool | str
             Add markers for sensor locations to the plot. Accepts matplotlib
             plot format string (e.g., 'r+' for red plusses). If True,
@@ -486,3 +573,95 @@ class CSP(TransformerMixin, EstimatorMixin):
                                     contours=contours,
                                     image_interp=image_interp, show=show,
                                     head_pos=head_pos)
+
+
+def _ajd_pham(X, eps=1e-6, max_iter=15):
+    """Approximate joint diagonalization based on Pham's algorithm.
+
+    This is a direct implementation of the PHAM's AJD algorithm [1].
+
+    Parameters
+    ----------
+    X : ndarray, shape (n_epochs, n_channels, n_channels)
+        A set of covariance matrices to diagonalize.
+    eps : float, defaults to 1e-6
+        The tolerance for stoping criterion.
+    max_iter : int, defaults to 1000
+        The maximum number of iteration to reach convergence.
+
+    Returns
+    -------
+    V : ndarray, shape (n_channels, n_channels)
+        The diagonalizer.
+    D : ndarray, shape (n_epochs, n_channels, n_channels)
+        The set of quasi diagonal matrices.
+
+    References
+    ----------
+    [1] Pham, Dinh Tuan. "Joint approximate diagonalization of positive
+    definite Hermitian matrices." SIAM Journal on Matrix Analysis and
+    Applications 22, no. 4 (2001): 1136-1152.
+
+    """
+    # Adapted from http://github.com/alexandrebarachant/pyRiemann
+    n_epochs = X.shape[0]
+
+    # Reshape input matrix
+    A = np.concatenate(X, axis=0).T
+
+    # Init variables
+    n_times, n_m = A.shape
+    V = np.eye(n_times)
+    epsilon = n_times * (n_times - 1) * eps
+
+    for it in range(max_iter):
+        decr = 0
+        for ii in range(1, n_times):
+            for jj in range(ii):
+                Ii = np.arange(ii, n_m, n_times)
+                Ij = np.arange(jj, n_m, n_times)
+
+                c1 = A[ii, Ii]
+                c2 = A[jj, Ij]
+
+                g12 = np.mean(A[ii, Ij] / c1)
+                g21 = np.mean(A[ii, Ij] / c2)
+
+                omega21 = np.mean(c1 / c2)
+                omega12 = np.mean(c2 / c1)
+                omega = np.sqrt(omega12 * omega21)
+
+                tmp = np.sqrt(omega21 / omega12)
+                tmp1 = (tmp * g12 + g21) / (omega + 1)
+                tmp2 = (tmp * g12 - g21) / max(omega - 1, 1e-9)
+
+                h12 = tmp1 + tmp2
+                h21 = np.conj((tmp1 - tmp2) / tmp)
+
+                decr += n_epochs * (g12 * np.conj(h12) + g21 * h21) / 2.0
+
+                tmp = 1 + 1.j * 0.5 * np.imag(h12 * h21)
+                tmp = np.real(tmp + np.sqrt(tmp ** 2 - h12 * h21))
+                tau = np.array([[1, -h12 / tmp], [-h21 / tmp, 1]])
+
+                A[[ii, jj], :] = np.dot(tau, A[[ii, jj], :])
+                tmp = np.c_[A[:, Ii], A[:, Ij]]
+                tmp = np.reshape(tmp, (n_times * n_epochs, 2), order='F')
+                tmp = np.dot(tmp, tau.T)
+
+                tmp = np.reshape(tmp, (n_times, n_epochs * 2), order='F')
+                A[:, Ii] = tmp[:, :n_epochs]
+                A[:, Ij] = tmp[:, n_epochs:]
+                V[[ii, jj], :] = np.dot(tau, V[[ii, jj], :])
+        if decr < epsilon:
+            break
+    D = np.reshape(A, (n_times, n_m / n_times, n_times)).transpose(1, 0, 2)
+    return V, D
+
+
+def _check_deprecate(epochs_data, X):
+    """Aux. function to CSP to deal with the change param name."""
+    if epochs_data is not None:
+        X = epochs_data
+        warn('epochs_data will be deprecated in mne 0.14. Use X instead')
+    return X
