@@ -4,7 +4,9 @@
 #
 # License: BSD (3-clause)
 
+from collections import Counter
 import os
+
 import numpy as np
 from scipy.linalg import inv
 from threading import Thread
@@ -18,7 +20,8 @@ from ..utils import logger
 try:
     from mayavi.core.ui.mayavi_scene import MayaviScene
     from mayavi.tools.mlab_scene_model import MlabSceneModel
-    from pyface.api import confirm, error, FileDialog, OK, YES, information
+    from pyface.api import (confirm, error, FileDialog, OK, YES, information,
+                            ProgressDialog)
     from traits.api import (HasTraits, HasPrivateTraits, cached_property,
                             Instance, Property, Bool, Button, Enum, File,
                             Float, Int, List, Str, Array, DelegatesTo)
@@ -34,10 +37,12 @@ except Exception:
         Str = Array = spring = View = Item = HGroup = VGroup = EnumEditor = \
         NoButtons = CheckListEditor = SceneEditor = TextEditor = trait_wraith
 
-from ..io.kit.kit import RawKIT, KIT
-from ..transforms import (apply_trans, als_ras_trans, als_ras_trans_mm,
+from ..io.constants import FIFF
+from ..io.kit.kit import RawKIT, KIT, _make_stim_channel, _default_stim_chs
+from ..transforms import (apply_trans, als_ras_trans,
                           get_ras_to_neuromag_trans, Transform)
 from ..coreg import _decimate_points, fit_matched_points
+from ..event import _find_events
 from ._marker_gui import CombineMarkersPanel, CombineMarkersModel
 from ._help import read_tooltips
 from ._viewer import (HeadViewController, headview_item, PointObject,
@@ -48,12 +53,12 @@ use_editor = CheckListEditor(cols=5, values=[(i, str(i)) for i in range(5)])
 backend_is_wx = False  # is there a way to determine this?
 if backend_is_wx:
     # wx backend allows labels for wildcards
-    hsp_points_wildcard = ['Head Shape Points (*.txt)|*.txt']
-    hsp_fid_wildcard = ['Head Shape Fiducials (*.txt)|*.txt']
+    hsp_wildcard = ['Head Shape Points (*.hsp;*.txt)|*.hsp;*.txt']
+    elp_wildcard = ['Head Shape Fiducials (*.elp;*.txt)|*.elp;*.txt']
     kit_con_wildcard = ['Continuous KIT Files (*.sqd;*.con)|*.sqd;*.con']
 else:
-    hsp_points_wildcard = ['*.txt']
-    hsp_fid_wildcard = ['*.txt']
+    hsp_wildcard = ['*.hsp;*.txt']
+    elp_wildcard = ['*.elp;*.txt']
     kit_con_wildcard = ['*.sqd;*.con']
 
 
@@ -71,13 +76,11 @@ class Kit2FiffModel(HasPrivateTraits):
     # Input Traits
     markers = Instance(CombineMarkersModel, ())
     sqd_file = File(exists=True, filter=kit_con_wildcard)
-    hsp_file = File(exists=True, filter=hsp_points_wildcard, desc="Digitizer "
-                    "head shape")
-    fid_file = File(exists=True, filter=hsp_fid_wildcard, desc="Digitizer "
-                    "fiducials")
+    hsp_file = File(exists=True, filter=hsp_wildcard)
+    fid_file = File(exists=True, filter=elp_wildcard)
     stim_coding = Enum(">", "<", "channel")
     stim_chs = Str("")
-    stim_chs_array = Property(depends_on='stim_chs')
+    stim_chs_array = Property(depends_on=['raw', 'stim_chs', 'stim_coding'])
     stim_chs_ok = Property(depends_on='stim_chs_array')
     stim_chs_comment = Property(depends_on='stim_chs_array')
     stim_slope = Enum("-", "+")
@@ -104,17 +107,27 @@ class Kit2FiffModel(HasPrivateTraits):
     dev_head_trans = Property(depends_on=['elp', 'mrk', 'use_mrk'])
     head_dev_trans = Property(depends_on=['dev_head_trans'])
 
+    # event preview
+    raw = Property(depends_on='sqd_file')
+    misc_chs = Property(List, depends_on='raw')
+    misc_chs_desc = Property(Str, depends_on='misc_chs')
+    misc_data = Property(Array, depends_on='raw')
+    can_test_stim = Property(Bool, depends_on='raw')
+
     # info
     sqd_fname = Property(Str, depends_on='sqd_file')
     hsp_fname = Property(Str, depends_on='hsp_file')
     fid_fname = Property(Str, depends_on='fid_file')
-    can_save = Property(Bool, depends_on=['stim_chs_ok', 'sqd_file', 'fid',
+    can_save = Property(Bool, depends_on=['stim_chs_ok', 'fid',
                                           'elp', 'hsp', 'dev_head_trans'])
 
+    # Show GUI feedback (like error messages and progress bar)
+    show_gui = Bool(False)
+
     @cached_property
     def _get_can_save(self):
         "Only allow saving when either all or no head shape elements are set."
-        if not self.stim_chs_ok or not self.sqd_file:
+        if not self.stim_chs_ok:
             return False
 
         has_all_hsp = (np.any(self.dev_head_trans) and np.any(self.hsp) and
@@ -125,6 +138,10 @@ class Kit2FiffModel(HasPrivateTraits):
         has_any_hsp = self.hsp_file or self.fid_file or np.any(self.mrk)
         return not has_any_hsp
 
+    @cached_property
+    def _get_can_test_stim(self):
+        return self.raw is not None
+
     @cached_property
     def _get_dev_head_trans(self):
         if (self.mrk is None) or not np.any(self.fid):
@@ -135,9 +152,10 @@ class Kit2FiffModel(HasPrivateTraits):
 
         n_use = len(self.use_mrk)
         if n_use < 3:
-            error(None, "Estimating the device head transform requires at "
-                  "least 3 marker points. Please adjust the markers used.",
-                  "Not Enough Marker Points")
+            if self.show_gui:
+                error(None, "Estimating the device head transform requires at "
+                      "least 3 marker points. Please adjust the markers used.",
+                      "Not Enough Marker Points")
             return
         elif n_use < 5:
             src_pts = src_pts[self.use_mrk]
@@ -164,9 +182,10 @@ class Kit2FiffModel(HasPrivateTraits):
             if len(pts) < 8:
                 raise ValueError("File contains %i points, need 8" % len(pts))
         except Exception as err:
-            error(None, str(err), "Error Reading Fiducials")
+            if self.show_gui:
+                error(None, str(err), "Error Reading Fiducials")
             self.reset_traits(['fid_file'])
-            raise
+            raise err
         else:
             return pts
 
@@ -218,18 +237,61 @@ class Kit2FiffModel(HasPrivateTraits):
                        "which is more than the recommended maximum ({n_rec}). "
                        "The file will be automatically downsampled, which "
                        "might take a while. A better way to downsample is "
-                       "using FastScan.")
-                msg = msg.format(n_in=n_pts, n_rec=KIT.DIG_POINTS)
-                information(None, msg, "Too Many Head Shape Points")
+                       "using FastScan.".
+                       format(n_in=n_pts, n_rec=KIT.DIG_POINTS))
+                if self.show_gui:
+                    information(None, msg, "Too Many Head Shape Points")
                 pts = _decimate_points(pts, 5)
 
         except Exception as err:
-            error(None, str(err), "Error Reading Head Shape")
+            if self.show_gui:
+                error(None, str(err), "Error Reading Head Shape")
             self.reset_traits(['hsp_file'])
             raise
         else:
             return pts
 
+    @cached_property
+    def _get_misc_chs(self):
+        if not self.raw:
+            return
+        return [i for i, ch in enumerate(self.raw.info['chs']) if
+                ch['kind'] == FIFF.FIFFV_MISC_CH]
+
+    @cached_property
+    def _get_misc_chs_desc(self):
+        if self.misc_chs is None:
+            return "No SQD file selected..."
+        elif np.all(np.diff(self.misc_chs) == 1):
+            return "%i:%i" % (self.misc_chs[0], self.misc_chs[-1] + 1)
+        else:
+            return "%i... (discontinuous)" % self.misc_chs[0]
+
+    @cached_property
+    def _get_misc_data(self):
+        if not self.raw:
+            return
+        if self.show_gui:
+            # progress dialog with indefinite progress bar
+            prog = ProgressDialog(title="Loading SQD data...",
+                                  message="Loading stim channel data from SQD "
+                                  "file ...")
+            prog.open()
+            prog.update(0)
+        else:
+            prog = None
+
+        try:
+            data, times = self.raw[self.misc_chs]
+        except Exception as err:
+            if self.show_gui:
+                error(None, str(err), "Error Creating FsAverage")
+            raise err
+        finally:
+            if self.show_gui:
+                prog.close()
+        return data
+
     @cached_property
     def _get_mrk(self):
         return apply_trans(als_ras_trans, self.markers.mrk3.points)
@@ -238,11 +300,23 @@ class Kit2FiffModel(HasPrivateTraits):
     def _get_polhemus_neuromag_trans(self):
         if self.elp_raw is None:
             return
-        pts = apply_trans(als_ras_trans_mm, self.elp_raw[:3])
-        nasion, lpa, rpa = pts
+        nasion, lpa, rpa = apply_trans(als_ras_trans, self.elp_raw[:3])
         trans = get_ras_to_neuromag_trans(nasion, lpa, rpa)
-        trans = np.dot(trans, als_ras_trans_mm)
-        return trans
+        return np.dot(trans, als_ras_trans)
+
+    @cached_property
+    def _get_raw(self):
+        if not self.sqd_file:
+            return
+        try:
+            return RawKIT(self.sqd_file, stim=None)
+        except Exception as err:
+            self.reset_traits(['sqd_file'])
+            if self.show_gui:
+                error(None, "Error reading SQD data file: %s (Check the "
+                      "terminal output for details)" % str(err),
+                      "Error Reading SQD file")
+            raise err
 
     @cached_property
     def _get_sqd_fname(self):
@@ -253,25 +327,33 @@ class Kit2FiffModel(HasPrivateTraits):
 
     @cached_property
     def _get_stim_chs_array(self):
-        if not self.stim_chs.strip():
-            return True
-        try:
-            out = eval("r_[%s]" % self.stim_chs, vars(np))
-            if out.dtype.kind != 'i':
-                raise TypeError("Need array of int")
-        except:
-            return None
+        if self.raw is None:
+            return
+        elif not self.stim_chs.strip():
+            picks = _default_stim_chs(self.raw.info)
         else:
-            return out
+            try:
+                picks = eval("r_[%s]" % self.stim_chs, vars(np))
+                if picks.dtype.kind != 'i':
+                    raise TypeError("Need array of int")
+            except:
+                return None
+
+        if self.stim_coding == '<':  # Big-endian
+            return picks[::-1]
+        else:
+            return picks
 
     @cached_property
     def _get_stim_chs_comment(self):
-        if self.stim_chs_array is None:
+        if self.raw is None:
+            return ""
+        elif not self.stim_chs_ok:
             return "Invalid!"
-        elif self.stim_chs_array is True:
-            return "Ok: Default channels"
+        elif not self.stim_chs.strip():
+            return "Default:  The first 8 MISC channels"
         else:
-            return "Ok: %i channels" % len(self.stim_chs_array)
+            return "Ok:  %i channels" % len(self.stim_chs_array)
 
     @cached_property
     def _get_stim_chs_ok(self):
@@ -283,19 +365,27 @@ class Kit2FiffModel(HasPrivateTraits):
         self.reset_traits(['sqd_file', 'hsp_file', 'fid_file', 'use_mrk'])
 
     def get_event_info(self):
-        """
-        Return a string with the number of events found for each trigger value
-        """
-        if len(self.events) == 0:
-            return "No events found."
+        """Count events with current stim channel settings
 
-        count = ["Events found:"]
-        events = np.array(self.events)
-        for i in np.unique(events):
-            n = np.sum(events == i)
-            count.append('%3i: %i' % (i, n))
-
-        return os.linesep.join(count)
+        Returns
+        -------
+        event_count : Counter
+            Counter mapping event ID to number of occurrences.
+        """
+        if self.misc_data is None:
+            return
+        idx = [self.misc_chs.index(ch) for ch in self.stim_chs_array]
+        data = self.misc_data[idx]
+        if self.stim_coding == 'channel':
+            coding = 'channel'
+        else:
+            coding = 'binary'
+        stim_ch = _make_stim_channel(data, self.stim_slope,
+                                     self.stim_threshold, coding,
+                                     self.stim_chs_array)
+        events = _find_events(stim_ch, self.raw.first_samp, consecutive=True,
+                              min_samples=3)
+        return Counter(events[:, 2])
 
     def get_raw(self, preload=False):
         """Create a raw object based on the current model settings
@@ -304,30 +394,17 @@ class Kit2FiffModel(HasPrivateTraits):
             raise ValueError("Not all necessary parameters are set")
 
         # stim channels and coding
-        if self.stim_chs_array is True:
-            if self.stim_coding == 'channel':
-                stim_code = 'channel'
-                raise NotImplementedError("Finding default event channels")
-            else:
-                stim = self.stim_coding
-                stim_code = 'binary'
+        if self.stim_coding == 'channel':
+            stim_code = 'channel'
+        elif self.stim_coding in '<>':
+            stim_code = 'binary'
         else:
-            stim = self.stim_chs_array
-            if self.stim_coding == 'channel':
-                stim_code = 'channel'
-            elif self.stim_coding == '<':
-                stim_code = 'binary'
-            elif self.stim_coding == '>':
-                # if stim is
-                stim = stim[::-1]
-                stim_code = 'binary'
-            else:
-                raise RuntimeError("stim_coding=%r" % self.stim_coding)
+            raise RuntimeError("stim_coding=%r" % self.stim_coding)
 
         logger.info("Creating raw with stim=%r, slope=%r, stim_code=%r, "
-                    "stimthresh=%r", stim, self.stim_slope, stim_code,
-                    self.stim_threshold)
-        raw = RawKIT(self.sqd_file, preload=preload, stim=stim,
+                    "stimthresh=%r", self.stim_chs_array, self.stim_slope,
+                    stim_code, self.stim_threshold)
+        raw = RawKIT(self.sqd_file, preload=preload, stim=self.stim_chs_array,
                      slope=self.stim_slope, stim_code=stim_code,
                      stimthresh=self.stim_threshold)
 
@@ -375,6 +452,10 @@ class Kit2FiffPanel(HasPrivateTraits):
     sqd_fname = DelegatesTo('model')
     hsp_fname = DelegatesTo('model')
     fid_fname = DelegatesTo('model')
+    misc_chs_desc = DelegatesTo('model')
+    can_test_stim = DelegatesTo('model')
+    test_stim = Button(label="Find Events")
+    plot_raw = Button(label="Plot Raw")
 
     # Source Files
     reset_dig = Button
@@ -399,15 +480,20 @@ class Kit2FiffPanel(HasPrivateTraits):
         VGroup(VGroup(Item('sqd_file', label="Data",
                            tooltip=tooltips['sqd_file']),
                       Item('sqd_fname', show_label=False, style='readonly'),
-                      Item('hsp_file', label='Dig Head Shape'),
+                      Item('hsp_file', label='Digitizer\nHead Shape',
+                           tooltip=tooltips['hsp_file']),
                       Item('hsp_fname', show_label=False, style='readonly'),
-                      Item('fid_file', label='Dig Points'),
+                      Item('fid_file', label='Digitizer\nFiducials',
+                           tooltip=tooltips['fid_file']),
                       Item('fid_fname', show_label=False, style='readonly'),
                       Item('reset_dig', label='Clear Digitizer Files',
                            show_label=False),
-                      Item('use_mrk', editor=use_editor, style='custom'),
+                      Item('use_mrk', editor=use_editor, style='custom',
+                           tooltip=tooltips['use_mrk']),
                       label="Sources", show_border=True),
-               VGroup(Item('stim_slope', label="Event Onset", style='custom',
+               VGroup(Item('misc_chs_desc', label='MISC Channels',
+                           style='readonly'),
+                      Item('stim_slope', label="Event Onset", style='custom',
                            tooltip=tooltips['stim_slope'],
                            editor=EnumEditor(
                                values={'+': '2:Peak (0 to 5 V)',
@@ -423,9 +509,15 @@ class Kit2FiffPanel(HasPrivateTraits):
                            tooltip=tooltips["stim_chs"],
                            editor=TextEditor(evaluate_name='stim_chs_ok',
                                              auto_set=True)),
-                      Item('stim_chs_comment', label='>', style='readonly'),
+                      Item('stim_chs_comment', label='Evaluation',
+                           style='readonly', show_label=False),
                       Item('stim_threshold', label='Threshold',
                            tooltip=tooltips['stim_threshold']),
+                      HGroup(Item('test_stim', enabled_when='can_test_stim',
+                                  show_label=False),
+                             Item('plot_raw', enabled_when='can_test_stim',
+                                  show_label=False),
+                             show_labels=False),
                       label='Events', show_border=True),
                HGroup(Item('save_as', enabled_when='can_save'), spring,
                       'clear_all', show_labels=False),
@@ -467,11 +559,11 @@ class Kit2FiffPanel(HasPrivateTraits):
         # setup mayavi visualization
         m = self.model
         self.fid_obj = PointObject(scene=self.scene, color=(25, 225, 25),
-                                   point_scale=5e-3)
+                                   point_scale=5e-3, name='Fiducials')
         self.elp_obj = PointObject(scene=self.scene, color=(50, 50, 220),
-                                   point_scale=1e-2, opacity=.2)
+                                   point_scale=1e-2, opacity=.2, name='ELP')
         self.hsp_obj = PointObject(scene=self.scene, color=(200, 200, 200),
-                                   point_scale=2e-3)
+                                   point_scale=2e-3, name='HSP')
         if not _testing_mode():
             for name, obj in zip(['fid', 'elp', 'hsp'],
                                  [self.fid_obj, self.elp_obj, self.hsp_obj]):
@@ -490,6 +582,9 @@ class Kit2FiffPanel(HasPrivateTraits):
         else:
             return ''
 
+    def _plot_raw_fired(self):
+        self.model.raw.plot()
+
     def _reset_dig_fired(self):
         self.reset_traits(['hsp_file', 'fid_file'])
 
@@ -527,10 +622,28 @@ class Kit2FiffPanel(HasPrivateTraits):
         self.queue.put((raw, fname))
         self.queue_len += 1
 
+    def _test_stim_fired(self):
+        try:
+            events = self.model.get_event_info()
+        except Exception as err:
+            error(None, "Error reading events from SQD data file: %s (Check "
+                  "the terminal output for details)" % str(err),
+                  "Error Reading events from SQD file")
+            raise err
+
+        if len(events) == 0:
+            information(None, "No events were found with the current "
+                        "settings.", "No Events Found")
+        else:
+            lines = ["Events found (ID: n events):"]
+            for id_ in sorted(events):
+                lines.append("%3i: \t%i" % (id_, events[id_]))
+            information(None, '\n'.join(lines), "Events in SQD File")
+
 
 class Kit2FiffFrame(HasTraits):
     """GUI for interpolating between two KIT marker files"""
-    model = Instance(Kit2FiffModel, ())
+    model = Instance(Kit2FiffModel, kw={'show_gui': True})
     scene = Instance(MlabSceneModel, ())
     headview = Instance(HeadViewController)
     marker_panel = Instance(CombineMarkersPanel)
