@@ -35,7 +35,7 @@ def test_mri_model():
 
     bem_fname = os.path.basename(model.bem.file)
     assert_false(model.can_reset)
-    assert_equal(bem_fname, 'sample-head.fif')
+    assert_equal(bem_fname, 'lh.seghead')
 
     model.save(tgt_fname)
     assert_equal(model.fid_file, tgt_fname)
