@@ -11,7 +11,7 @@ from nose.tools import assert_true, assert_false, assert_equal
 
 import mne
 from mne.io.kit.tests import data_dir as kit_data_dir
-from mne.io import Raw
+from mne.io import read_raw_fif
 from mne.utils import _TempDir, requires_traits, run_tests_if_main
 
 mrk_pre_path = os.path.join(kit_data_dir, 'test_mrk_pre.sqd')
@@ -26,25 +26,35 @@ warnings.simplefilter('always')
 
 @requires_traits
 def test_kit2fiff_model():
-    """Test CombineMarkersModel Traits Model"""
+    """Test CombineMarkersModel Traits Model."""
     from mne.gui._kit2fiff_gui import Kit2FiffModel, Kit2FiffPanel
     tempdir = _TempDir()
     tgt_fname = os.path.join(tempdir, 'test-raw.fif')
 
     model = Kit2FiffModel()
     assert_false(model.can_save)
+    assert_equal(model.misc_chs_desc, "No SQD file selected...")
+    assert_equal(model.stim_chs_comment, "")
     model.markers.mrk1.file = mrk_pre_path
     model.markers.mrk2.file = mrk_post_path
     model.sqd_file = sqd_path
+    assert_equal(model.misc_chs_desc, "160:192")
     model.hsp_file = hsp_path
     assert_false(model.can_save)
     model.fid_file = fid_path
     assert_true(model.can_save)
 
+    # events
+    model.stim_slope = '+'
+    assert_equal(model.get_event_info(), {1: 2})
+    model.stim_slope = '-'
+    assert_equal(model.get_event_info(), {254: 2, 255: 2})
+
     # stim channels
     model.stim_chs = "181:184, 186"
     assert_array_equal(model.stim_chs_array, [181, 182, 183, 186])
     assert_true(model.stim_chs_ok)
+    assert_equal(model.get_event_info(), {})
     model.stim_chs = "181:184, bad"
     assert_false(model.stim_chs_ok)
     assert_false(model.can_save)
@@ -54,10 +64,10 @@ def test_kit2fiff_model():
     # export raw
     raw_out = model.get_raw()
     raw_out.save(tgt_fname)
-    raw = Raw(tgt_fname)
+    raw = read_raw_fif(tgt_fname, add_eeg_ref=False)
 
     # Compare exported raw with the original binary conversion
-    raw_bin = Raw(fif_path)
+    raw_bin = read_raw_fif(fif_path, add_eeg_ref=False)
     trans_bin = raw.info['dev_head_t']['trans']
     want_keys = list(raw_bin.info.keys())
     assert_equal(sorted(want_keys), sorted(list(raw.info.keys())))
