@@ -71,11 +71,12 @@ KIT_NY.HPFS = [0, 1, 3]
 KIT_NY.LPFS = [10, 20, 50, 100, 200, 500, 1000, 2000]
 
 
-# Maryland-system channel information
-# Virtually the same as the NY-system except new ADC circa July 2014
+# University of Maryland - system channel information
+# Virtually the same as the NY-system except new ADC in July 2014
 # 16-bit A-to-D converter, one bit for signed integer. range +/- 32768
-KIT_MD = Bunch(**KIT_NY)
-KIT_MD.DYNAMIC_RANGE = 2 ** 15
+KIT_UMD = KIT_NY
+KIT_UMD_2014 = Bunch(**KIT_UMD)
+KIT_UMD_2014.DYNAMIC_RANGE = 2 ** 15
 
 
 # AD-system channel information
@@ -107,17 +108,41 @@ KIT_AD.LPFS = [10, 20, 50, 100, 200, 500, 1000, 10000]
 
 
 # KIT recording system is encoded in the SQD file as integer:
-KIT_CONSTANTS = {32: KIT_NY,  # NYU-NY, July 7, 2008 -
-                 33: KIT_NY,  # NYU-NY, January 24, 2009 -
-                 34: KIT_NY,  # NYU-NY, January 22, 2010 -
-                 # 440 NYU-AD, initial launch May 20, 2011 -
-                 441: KIT_AD,  # NYU-AD more channels July 11, 2012 -
-                 442: KIT_AD,  # NYU-AD move to NYUAD campus Nov 20, 2014 -
-                 51: KIT_NY,  # UMD
-                 52: KIT_MD,  # UMD update to 16 bit ADC, July 4, 2014 -
-                 53: KIT_MD}  # UMD December 4, 2014 -
+KIT.SYSTEM_NYU_2008 = 32  # NYU-NY, July 7, 2008 -
+KIT.SYSTEM_NYU_2009 = 33  # NYU-NY, January 24, 2009 -
+KIT.SYSTEM_NYU_2010 = 34  # NYU-NY, January 22, 2010 -
+KIT.SYSTEM_NYUAD_2011 = 440  # NYU-AD initial launch May 20, 2011 -
+KIT.SYSTEM_NYUAD_2012 = 441  # NYU-AD more channels July 11, 2012 -
+KIT.SYSTEM_NYUAD_2014 = 442  # NYU-AD move to NYUAD campus Nov 20, 2014 -
+KIT.SYSTEM_UMD_2004 = 51  # UMD Marie Mount Hall, October 1, 2004 -
+KIT.SYSTEM_UMD_2014_07 = 52  # UMD update to 16 bit ADC, July 4, 2014 -
+KIT.SYSTEM_UMD_2014_12 = 53  # UMD December 4, 2014 -
 
-SYSNAMES = {33: 'NYU 160ch System since Jan24 2009',
-            34: 'NYU 160ch System since Jan24 2009',
-            441: "New York University Abu Dhabi",
-            442: "New York University Abu Dhabi"}
+KIT_CONSTANTS = {KIT.SYSTEM_NYU_2008: KIT_NY,
+                 KIT.SYSTEM_NYU_2009: KIT_NY,
+                 KIT.SYSTEM_NYU_2010: KIT_NY,
+                 KIT.SYSTEM_NYUAD_2011: KIT_AD,
+                 KIT.SYSTEM_NYUAD_2012: KIT_AD,
+                 KIT.SYSTEM_NYUAD_2014: KIT_AD,
+                 KIT.SYSTEM_UMD_2004: KIT_UMD,
+                 KIT.SYSTEM_UMD_2014_07: KIT_UMD_2014,
+                 KIT.SYSTEM_UMD_2014_12: KIT_UMD_2014}
+
+KIT_LAYOUT = {KIT.SYSTEM_NYU_2008: 'KIT-157',
+              KIT.SYSTEM_NYU_2009: 'KIT-157',
+              KIT.SYSTEM_NYU_2010: 'KIT-157',
+              KIT.SYSTEM_NYUAD_2011: 'KIT-AD',
+              KIT.SYSTEM_NYUAD_2012: 'KIT-AD',
+              KIT.SYSTEM_NYUAD_2014: 'KIT-AD',
+              KIT.SYSTEM_UMD_2004: None,
+              KIT.SYSTEM_UMD_2014_07: None,
+              KIT.SYSTEM_UMD_2014_12: 'KIT-UMD-3'}
+
+# Names stored along with ID in SQD files
+SYSNAMES = {KIT.SYSTEM_NYU_2009: 'NYU 160ch System since Jan24 2009',
+            KIT.SYSTEM_NYU_2010: 'NYU 160ch System since Jan24 2009',
+            KIT.SYSTEM_NYUAD_2012: "New York University Abu Dhabi",
+            KIT.SYSTEM_NYUAD_2014: "New York University Abu Dhabi",
+            KIT.SYSTEM_UMD_2004: "University of Maryland",
+            KIT.SYSTEM_UMD_2014_07: "University of Maryland",
+            KIT.SYSTEM_UMD_2014_12: "University of Maryland"}
