@@ -18,7 +18,7 @@ from .constants import FIFF
 from .pick import pick_types
 from .write import (write_int, write_float, write_string, write_name_list,
                     write_float_matrix, end_block, start_block)
-from ..utils import logger, verbose, warn
+from ..utils import logger, verbose, warn, deprecated
 from ..externals.six import string_types
 
 
@@ -105,13 +105,19 @@ class ProjMixin(object):
                                              check_active=False, sort=False)
         return self
 
+    @deprecated('This function is deprecated and will be removed in 0.14. '
+                'Use set_eeg_reference() instead.')
     def add_eeg_average_proj(self):
-        """Add an average EEG reference projector if one does not exist
-        """
+        """Add an average EEG reference projector if one does not exist."""
         if _needs_eeg_average_ref_proj(self.info):
             # Don't set as active, since we haven't applied it
             eeg_proj = make_eeg_average_ref_proj(self.info, activate=False)
             self.add_proj(eeg_proj)
+        elif self.info.get('custom_ref_applied', False):
+            raise RuntimeError('Cannot add an average EEG reference '
+                               'projection since a custom reference has been '
+                               'applied to the data earlier.')
+
         return self
 
     def apply_proj(self):
@@ -696,12 +702,17 @@ def make_eeg_average_ref_proj(info, activate=True, verbose=None):
     return eeg_proj
 
 
-def _has_eeg_average_ref_proj(projs):
-    """Determine if a list of projectors has an average EEG ref"""
+def _has_eeg_average_ref_proj(projs, check_active=False):
+    """Determine if a list of projectors has an average EEG ref
+
+    Optionally, set check_active=True to additionally check if the CAR
+    has already been applied.
+    """
     for proj in projs:
         if (proj['desc'] == 'Average EEG reference' or
                 proj['kind'] == FIFF.FIFFV_MNE_PROJ_ITEM_EEG_AVREF):
-            return True
+            if not check_active or proj['active']:
+                return True
     return False
 
 
