@@ -14,10 +14,9 @@ import re
 import numpy as np
 from scipy import linalg, sparse
 
-from .fixes import digitize, in1d
 from .utils import (get_subjects_dir, _check_subject, logger, verbose, warn,
                     _check_copy_dep)
-from .source_estimate import (morph_data, SourceEstimate,
+from .source_estimate import (morph_data, SourceEstimate, _center_of_mass,
                               spatial_src_connectivity)
 from .source_space import add_source_space_distances
 from .surface import read_surface, fast_cross_3d, mesh_edges, mesh_dist
@@ -361,7 +360,7 @@ class Label(object):
             raise TypeError("Need: Label or BiHemiLabel. Got: %r" % other)
 
         if self.hemi == other.hemi:
-            keep = in1d(self.vertices, other.vertices, True, invert=True)
+            keep = np.in1d(self.vertices, other.vertices, True, invert=True)
         else:
             keep = np.arange(len(self.vertices))
 
@@ -422,7 +421,7 @@ class Label(object):
         elif self.hemi == 'rh':
             hemi_src = src[1]
 
-        if not np.all(in1d(self.vertices, hemi_src['vertno'])):
+        if not np.all(np.in1d(self.vertices, hemi_src['vertno'])):
             msg = "Source space does not contain all of the label's vertices"
             raise ValueError(msg)
 
@@ -436,11 +435,11 @@ class Label(object):
             nearest = hemi_src['nearest']
 
         # find new vertices
-        include = in1d(nearest, self.vertices, False)
+        include = np.in1d(nearest, self.vertices, False)
         vertices = np.nonzero(include)[0]
 
         # values
-        nearest_in_label = digitize(nearest[vertices], self.vertices, True)
+        nearest_in_label = np.digitize(nearest[vertices], self.vertices, True)
         values = self.values[nearest_in_label]
         # pos
         pos = hemi_src['rr'][vertices]
@@ -485,7 +484,7 @@ class Label(object):
         n_jobs : int
             Number of jobs to run in parallel
         copy : bool
-            This parameter has been deprecated and will be removed in 0.13.
+            This parameter has been deprecated and will be removed in 0.14.
             Use inst.copy() instead.
             Whether to return a new instance or modify in place.
         verbose : bool, str, int, or None
@@ -541,7 +540,7 @@ class Label(object):
         n_jobs : int
             Number of jobs to run in parallel.
         copy : bool
-            This parameter has been deprecated and will be removed in 0.13.
+            This parameter has been deprecated and will be removed in 0.14.
             Use inst.copy() instead.
             Whether to return a new instance or modify in place.
         verbose : bool, str, int, or None
@@ -583,7 +582,7 @@ class Label(object):
                          smooth=smooth, subjects_dir=subjects_dir,
                          warn=False, n_jobs=n_jobs)
         inds = np.nonzero(stc.data)[0]
-        label = _check_copy_dep(self, copy, default=True)
+        label = _check_copy_dep(self, copy)
         label.values = stc.data[inds, :].ravel()
         label.pos = np.zeros((len(inds), 3))
         if label.hemi == 'lh':
@@ -658,7 +657,7 @@ class Label(object):
         if vertices is None:
             vertices = np.arange(10242)
 
-        label_verts = vertices[in1d(vertices, self.vertices)]
+        label_verts = vertices[np.in1d(vertices, self.vertices)]
         return label_verts
 
     def get_tris(self, tris, vertices=None):
@@ -679,7 +678,7 @@ class Label(object):
             The subset of tris used by the label
         """
         vertices_ = self.get_vertices_used(vertices)
-        selection = np.all(in1d(tris, vertices_).reshape(tris.shape),
+        selection = np.all(np.in1d(tris, vertices_).reshape(tris.shape),
                            axis=1)
         label_tris = tris[selection]
         if len(np.unique(label_tris)) < len(vertices_):
@@ -698,6 +697,62 @@ class Label(object):
 
         return label_tris
 
+    def center_of_mass(self, subject=None, restrict_vertices=False,
+                       subjects_dir=None, surf='sphere'):
+        """Compute the center of mass of the label
+
+        This function computes the spatial center of mass on the surface
+        as in [1]_.
+
+        Parameters
+        ----------
+        subject : string | None
+            The subject the label is defined for.
+        restrict_vertices : bool | array of int | instance of SourceSpaces
+            If True, returned vertex will be one from the label. Otherwise,
+            it could be any vertex from surf. If an array of int, the
+            returned vertex will come from that array. If instance of
+            SourceSpaces (as of 0.13), the returned vertex will be from
+            the given source space. For most accuruate estimates, do not
+            restrict vertices.
+        subjects_dir : str, or None
+            Path to the SUBJECTS_DIR. If None, the path is obtained by using
+            the environment variable SUBJECTS_DIR.
+        surf : str
+            The surface to use for Euclidean distance center of mass
+            finding. The default here is "sphere", which finds the center
+            of mass on the spherical surface to help avoid potential issues
+            with cortical folding.
+
+        Returns
+        -------
+        vertex : int
+            Vertex of the spatial center of mass for the inferred hemisphere,
+            with each vertex weighted by its label value.
+
+        See Also
+        --------
+        SourceEstimate.center_of_mass
+        vertex_to_mni
+
+        Notes
+        -----
+        .. versionadded: 0.13
+
+        References
+        ----------
+        .. [1] Larson and Lee, "The cortical dynamics underlying effective
+               switching of auditory spatial attention", NeuroImage 2012.
+        """
+        if not isinstance(surf, string_types):
+            raise TypeError('surf must be a string, got %s' % (type(surf),))
+        subject = _check_subject(self.subject, subject)
+        if np.any(self.values < 0):
+            raise ValueError('Cannot compute COM with negative values')
+        vertex = _center_of_mass(self.vertices, self.values, self.hemi, surf,
+                                 subject, subjects_dir, restrict_vertices)
+        return vertex
+
 
 class BiHemiLabel(object):
     """A freesurfer/MNE label with vertices in both hemispheres
@@ -1002,7 +1057,7 @@ def _split_label_contig(label_to_split, subject=None, subjects_dir=None):
     for div, name, color in zip(label_divs, names, colors):
         # Get indices of dipoles within this division of the label
         verts = np.array(sorted(list(div)))
-        vert_indices = in1d(verts_arr, verts, assume_unique=True)
+        vert_indices = np.in1d(verts_arr, verts, assume_unique=True)
 
         # Set label attributes
         pos = label_to_split.pos[vert_indices]
