@@ -12,7 +12,7 @@ from .ssp import compute_proj_ecg, compute_proj_eog
 from .eog import find_eog_events, create_eog_epochs
 from .ecg import find_ecg_events, create_ecg_epochs
 from .ica import (ICA, ica_find_eog_events, ica_find_ecg_events,
-                  get_score_funcs, read_ica, run_ica)
+                  get_score_funcs, read_ica, run_ica, corrmap)
 from .bads import find_outliers
 from .stim import fix_stim_artifact
 from .maxwell import maxwell_filter
