@@ -9,19 +9,22 @@ import os
 import os.path as op
 import warnings
 
-from nose.tools import assert_true, assert_raises, assert_equal
+from nose.tools import assert_true, assert_raises, assert_equal, assert_false
 import numpy as np
 from numpy.testing import (assert_array_almost_equal, assert_array_equal,
                            assert_allclose)
 from scipy import stats
 from itertools import product
 
-from mne import Epochs, read_events, pick_types
+from mne import Epochs, read_events, pick_types, create_info, EpochsArray
 from mne.cov import read_cov
 from mne.preprocessing import (ICA, ica_find_ecg_events, ica_find_eog_events,
                                read_ica, run_ica)
-from mne.preprocessing.ica import get_score_funcs, corrmap, _get_ica_map
-from mne.io import Raw, Info
+from mne.preprocessing.ica import (get_score_funcs, corrmap, _get_ica_map,
+                                   _ica_explained_variance, _sort_components)
+from mne.io import read_raw_fif, Info, RawArray
+from mne.io.meas_info import _kind_dict
+from mne.io.pick import _DATA_CH_TYPES_SPLIT
 from mne.tests.common import assert_naming
 from mne.utils import (catch_logging, _TempDir, requires_sklearn, slow_test,
                        run_tests_if_main)
@@ -36,7 +39,6 @@ warnings.simplefilter('always')  # enable b/c these tests throw warnings
 data_dir = op.join(op.dirname(__file__), '..', '..', 'io', 'tests', 'data')
 raw_fname = op.join(data_dir, 'test_raw.fif')
 event_name = op.join(data_dir, 'test-eve.fif')
-evoked_nf_name = op.join(data_dir, 'test-nf-ave.fif')
 test_cov_name = op.join(data_dir, 'test-cov.fif')
 
 event_id, tmin, tmax = 1, -0.2, 0.2
@@ -52,16 +54,16 @@ except:
 
 @requires_sklearn
 def test_ica_full_data_recovery():
-    """Test recovery of full data when no source is rejected"""
+    """Test recovery of full data when no source is rejected."""
     # Most basic recovery
-    raw = Raw(raw_fname).crop(0.5, stop, copy=False)
-    raw.load_data()
+    raw = read_raw_fif(raw_fname, add_eeg_ref=False)
+    raw.crop(0.5, stop, copy=False).load_data()
     events = read_events(event_name)
     picks = pick_types(raw.info, meg=True, stim=False, ecg=False,
                        eog=False, exclude='bads')[:10]
     with warnings.catch_warnings(record=True):  # bad proj
         epochs = Epochs(raw, events[:4], event_id, tmin, tmax, picks=picks,
-                        baseline=(None, 0), preload=True)
+                        baseline=(None, 0), preload=True, add_eeg_ref=False)
     evoked = epochs.average()
     n_channels = 5
     data = raw._data[:n_channels].copy()
@@ -111,10 +113,10 @@ def test_ica_full_data_recovery():
 
 @requires_sklearn
 def test_ica_rank_reduction():
-    """Test recovery ICA rank reduction"""
+    """Test recovery ICA rank reduction."""
     # Most basic recovery
-    raw = Raw(raw_fname).crop(0.5, stop, copy=False)
-    raw.load_data()
+    raw = read_raw_fif(raw_fname, add_eeg_ref=False)
+    raw.crop(0.5, stop, copy=False).load_data()
     picks = pick_types(raw.info, meg=True, stim=False, ecg=False,
                        eog=False, exclude='bads')[:10]
     n_components = 5
@@ -140,9 +142,9 @@ def test_ica_rank_reduction():
 
 @requires_sklearn
 def test_ica_reset():
-    """Test ICA resetting"""
-    raw = Raw(raw_fname).crop(0.5, stop, copy=False)
-    raw.load_data()
+    """Test ICA resetting."""
+    raw = read_raw_fif(raw_fname, add_eeg_ref=False)
+    raw.crop(0.5, stop, copy=False).load_data()
     picks = pick_types(raw.info, meg=True, stim=False, ecg=False,
                        eog=False, exclude='bads')[:10]
 
@@ -168,9 +170,9 @@ def test_ica_reset():
 
 @requires_sklearn
 def test_ica_core():
-    """Test ICA on raw and epochs"""
-    raw = Raw(raw_fname).crop(1.5, stop, copy=False)
-    raw.load_data()
+    """Test ICA on raw and epochs."""
+    raw = read_raw_fif(raw_fname, add_eeg_ref=False)
+    raw.crop(1.5, stop, copy=False).load_data()
     picks = pick_types(raw.info, meg=True, stim=False, ecg=False,
                        eog=False, exclude='bads')
     # XXX. The None cases helped revealing bugs but are time consuming.
@@ -179,7 +181,7 @@ def test_ica_core():
     picks = pick_types(raw.info, meg=True, stim=False, ecg=False,
                        eog=False, exclude='bads')
     epochs = Epochs(raw, events[:4], event_id, tmin, tmax, picks=picks,
-                    baseline=(None, 0), preload=True)
+                    baseline=(None, 0), preload=True, add_eeg_ref=False)
     noise_cov = [None, test_cov]
     # removed None cases to speed up...
     n_components = [2, 1.0]  # for future dbg add cases
@@ -271,19 +273,19 @@ def test_ica_core():
 @slow_test
 @requires_sklearn
 def test_ica_additional():
-    """Test additional ICA functionality"""
+    """Test additional ICA functionality."""
     tempdir = _TempDir()
     stop2 = 500
-    raw = Raw(raw_fname).crop(1.5, stop, copy=False)
-    raw.load_data()
-    picks = pick_types(raw.info, meg=True, stim=False, ecg=False,
-                       eog=False, exclude='bads')
+    raw = read_raw_fif(raw_fname, add_eeg_ref=False)
+    raw.crop(1.5, stop, copy=False).load_data()
+    # XXX This breaks the tests :(
+    # raw.info['bads'] = [raw.ch_names[1]]
     test_cov = read_cov(test_cov_name)
     events = read_events(event_name)
     picks = pick_types(raw.info, meg=True, stim=False, ecg=False,
                        eog=False, exclude='bads')
     epochs = Epochs(raw, events[:4], event_id, tmin, tmax, picks=picks,
-                    baseline=(None, 0), preload=True)
+                    baseline=(None, 0), preload=True, add_eeg_ref=False)
     # test if n_components=None works
     with warnings.catch_warnings(record=True):
         ica = ICA(n_components=None,
@@ -294,7 +296,7 @@ def test_ica_additional():
     picks2 = pick_types(raw.info, meg=True, stim=False, ecg=False,
                         eog=True, exclude='bads')
     epochs_eog = Epochs(raw, events[:4], event_id, tmin, tmax, picks=picks2,
-                        baseline=(None, 0), preload=True)
+                        baseline=(None, 0), preload=True, add_eeg_ref=False)
 
     test_cov2 = test_cov.copy()
     ica = ICA(noise_cov=test_cov2, n_components=3, max_pca_components=4,
@@ -350,6 +352,15 @@ def test_ica_additional():
     with warnings.catch_warnings(record=True):
         ica.fit(raw, picks=None, decim=3)
     assert_true(ica.n_components_ == 4)
+    ica_var = _ica_explained_variance(ica, raw, normalize=True)
+    assert_true(np.all(ica_var[:-1] >= ica_var[1:]))
+
+    # test ica sorting
+    ica.exclude = [0]
+    ica.labels_ = dict(blink=[0], think=[1])
+    ica_sorted = _sort_components(ica, [3, 2, 1, 0], copy=True)
+    assert_equal(ica_sorted.exclude, [3])
+    assert_equal(ica_sorted.labels_, dict(blink=[3], think=[2]))
 
     # epochs extraction from raw fit
     assert_raises(RuntimeError, ica.get_sources, epochs)
@@ -367,7 +378,7 @@ def test_ica_additional():
         assert_true(sources.shape[1] == ica.n_components_)
 
         for exclude in [[], [0]]:
-            ica.exclude = [0]
+            ica.exclude = exclude
             ica.labels_ = {'foo': [0]}
             ica.save(test_ica_fname)
             ica_read = read_ica(test_ica_fname)
@@ -387,18 +398,24 @@ def test_ica_additional():
 
         # test filtering
         d1 = ica_raw._data[0].copy()
-        with warnings.catch_warnings(record=True):  # dB warning
-            ica_raw.filter(4, 20)
+        ica_raw.filter(4, 20, l_trans_bandwidth='auto',
+                       h_trans_bandwidth='auto', filter_length='auto',
+                       phase='zero', fir_window='hamming')
+        assert_equal(ica_raw.info['lowpass'], 20.)
+        assert_equal(ica_raw.info['highpass'], 4.)
         assert_true((d1 != ica_raw._data[0]).any())
         d1 = ica_raw._data[0].copy()
-        with warnings.catch_warnings(record=True):  # dB warning
-            ica_raw.notch_filter([10])
+        ica_raw.notch_filter([10], filter_length='auto', trans_bandwidth=10,
+                             phase='zero', fir_window='hamming')
         assert_true((d1 != ica_raw._data[0]).any())
 
         ica.n_pca_components = 2
+        ica.method = 'fake'
         ica.save(test_ica_fname)
         ica_read = read_ica(test_ica_fname)
         assert_true(ica.n_pca_components == ica_read.n_pca_components)
+        assert_equal(ica.method, ica_read.method)
+        assert_equal(ica.labels_, ica_read.labels_)
 
         # check type consistency
         attrs = ('mixing_matrix_ unmixing_matrix_ pca_components_ '
@@ -460,6 +477,11 @@ def test_ica_additional():
         assert_equal(len(scores), ica.n_components_)
         idx, scores = ica.find_bads_ecg(raw, method='correlation')
         assert_equal(len(scores), ica.n_components_)
+
+        idx, scores = ica.find_bads_eog(raw)
+        assert_equal(len(scores), ica.n_components_)
+
+        ica.labels_ = None
         idx, scores = ica.find_bads_ecg(epochs, method='ctps')
         assert_equal(len(scores), ica.n_components_)
         assert_raises(ValueError, ica.find_bads_ecg, epochs.average(),
@@ -467,8 +489,6 @@ def test_ica_additional():
         assert_raises(ValueError, ica.find_bads_ecg, raw,
                       method='crazy-coupling')
 
-        idx, scores = ica.find_bads_eog(raw)
-        assert_equal(len(scores), ica.n_components_)
         raw.info['chs'][raw.ch_names.index('EOG 061') - 1]['kind'] = 202
         idx, scores = ica.find_bads_eog(raw)
         assert_true(isinstance(scores, list))
@@ -517,7 +537,7 @@ def test_ica_additional():
     test_ica_fname = op.join(op.abspath(op.curdir), 'test-ica_raw.fif')
     ica.n_components = np.int32(ica.n_components)
     ica_raw.save(test_ica_fname, overwrite=True)
-    ica_raw2 = Raw(test_ica_fname, preload=True)
+    ica_raw2 = read_raw_fif(test_ica_fname, preload=True, add_eeg_ref=False)
     assert_allclose(ica_raw._data, ica_raw2._data, rtol=1e-5, atol=1e-4)
     ica_raw2.close()
     os.remove(test_ica_fname)
@@ -541,8 +561,9 @@ def test_ica_additional():
 
 @requires_sklearn
 def test_run_ica():
-    """Test run_ica function"""
-    raw = Raw(raw_fname, preload=True).crop(1.5, stop, copy=False)
+    """Test run_ica function."""
+    raw = read_raw_fif(raw_fname, add_eeg_ref=False)
+    raw.crop(1.5, stop, copy=False).load_data()
     params = []
     params += [(None, -1, slice(2), [0, 1])]  # varicance, kurtosis idx
     params += [(None, 'MEG 1531')]  # ECG / EOG channel params
@@ -556,9 +577,9 @@ def test_run_ica():
 
 @requires_sklearn
 def test_ica_reject_buffer():
-    """Test ICA data raw buffer rejection"""
-    raw = Raw(raw_fname).crop(1.5, stop, copy=False)
-    raw.load_data()
+    """Test ICA data raw buffer rejection."""
+    raw = read_raw_fif(raw_fname, add_eeg_ref=False)
+    raw.crop(1.5, stop, copy=False).load_data()
     picks = pick_types(raw.info, meg=True, stim=False, ecg=False,
                        eog=False, exclude='bads')
     ica = ICA(n_components=3, max_pca_components=4, n_pca_components=4)
@@ -574,9 +595,9 @@ def test_ica_reject_buffer():
 
 @requires_sklearn
 def test_ica_twice():
-    """Test running ICA twice"""
-    raw = Raw(raw_fname).crop(1.5, stop, copy=False)
-    raw.load_data()
+    """Test running ICA twice."""
+    raw = read_raw_fif(raw_fname, add_eeg_ref=False)
+    raw.crop(1.5, stop, copy=False).load_data()
     picks = pick_types(raw.info, meg='grad', exclude='bads')
     n_components = 0.9
     max_pca_components = None
@@ -597,10 +618,67 @@ def test_ica_twice():
 
 @requires_sklearn
 def test_fit_params():
-    """Test fit_params for ICA"""
+    """Test fit_params for ICA."""
     assert_raises(ValueError, ICA, fit_params=dict(extended=True))
     fit_params = {}
     ICA(fit_params=fit_params)  # test no side effects
     assert_equal(fit_params, {})
 
+
+@requires_sklearn
+def test_bad_channels():
+    """Test exception when unsupported channels are used."""
+    chs = [i for i in _kind_dict]
+    data_chs = _DATA_CH_TYPES_SPLIT + ['eog']
+    chs_bad = list(set(chs) - set(data_chs))
+    info = create_info(len(chs), 500, chs)
+    data = np.random.rand(len(chs), 50)
+    raw = RawArray(data, info)
+    data = np.random.rand(100, len(chs), 50)
+    epochs = EpochsArray(data, info)
+
+    n_components = 0.9
+    ica = ICA(n_components=n_components, method='fastica')
+
+    for inst in [raw, epochs]:
+        for ch in chs_bad:
+            # Test case for only bad channels
+            picks_bad1 = pick_types(inst.info, meg=False,
+                                    **{str(ch): True})
+            # Test case for good and bad channels
+            picks_bad2 = pick_types(inst.info, meg=True,
+                                    **{str(ch): True})
+            assert_raises(ValueError, ica.fit, inst, picks=picks_bad1)
+            assert_raises(ValueError, ica.fit, inst, picks=picks_bad2)
+        assert_raises(ValueError, ica.fit, inst, picks=[])
+
+
+@requires_sklearn
+def test_eog_channel():
+    """Test that EOG channel is included when performing ICA."""
+    raw = read_raw_fif(raw_fname, preload=True, add_eeg_ref=False)
+    events = read_events(event_name)
+    picks = pick_types(raw.info, meg=True, stim=True, ecg=False,
+                       eog=True, exclude='bads')
+    epochs = Epochs(raw, events, event_id, tmin, tmax, picks=picks,
+                    baseline=(None, 0), preload=True,
+                    add_eeg_ref=False)
+    n_components = 0.9
+    ica = ICA(n_components=n_components, method='fastica')
+    # Test case for MEG and EOG data. Should have EOG channel
+    for inst in [raw, epochs]:
+        picks1a = pick_types(inst.info, meg=True, stim=False, ecg=False,
+                             eog=False, exclude='bads')[:4]
+        picks1b = pick_types(inst.info, meg=False, stim=False, ecg=False,
+                             eog=True, exclude='bads')
+        picks1 = np.append(picks1a, picks1b)
+        ica.fit(inst, picks=picks1)
+        assert_true(any('EOG' in ch for ch in ica.ch_names))
+    # Test case for MEG data. Should have no EOG channel
+    for inst in [raw, epochs]:
+        picks1 = pick_types(inst.info, meg=True, stim=False, ecg=False,
+                            eog=False, exclude='bads')[:5]
+        ica.fit(inst, picks=picks1)
+        assert_false(any('EOG' in ch for ch in ica.ch_names))
+
 run_tests_if_main()
