@@ -17,14 +17,15 @@ from mne.chpi import read_head_pos, filter_chpi
 from mne.forward import _prep_meg_channels
 from mne.cov import _estimate_rank_meeg_cov
 from mne.datasets import testing
-from mne.io import Raw, proc_history, read_info, read_raw_bti, read_raw_kit
+from mne.io import (read_raw_fif, proc_history, read_info, read_raw_bti,
+                    read_raw_kit, _BaseRaw)
 from mne.preprocessing.maxwell import (
     maxwell_filter, _get_n_moments, _sss_basis_basic, _sh_complex_to_real,
     _sh_real_to_complex, _sh_negate, _bases_complex_to_real, _trans_sss_basis,
     _bases_real_to_complex, _sph_harm, _prep_mf_coils)
 from mne.tests.common import assert_meg_snr
 from mne.utils import (_TempDir, run_tests_if_main, slow_test, catch_logging,
-                       requires_version, object_diff)
+                       requires_version, object_diff, buggy_mkl_svd)
 from mne.externals.six import PY3
 
 warnings.simplefilter('always')  # Always throw warnings
@@ -76,6 +77,20 @@ ctc_mgh_fname = op.join(sss_path, 'ct_sparse_mgh.fif')
 sample_fname = op.join(data_path, 'MEG', 'sample',
                        'sample_audvis_trunc_raw.fif')
 
+triux_path = op.join(data_path, 'SSS', 'TRIUX')
+tri_fname = op.join(triux_path, 'triux_bmlhus_erm_raw.fif')
+tri_sss_fname = op.join(triux_path, 'triux_bmlhus_erm_raw_sss.fif')
+tri_sss_reg_fname = op.join(triux_path, 'triux_bmlhus_erm_regIn_raw_sss.fif')
+tri_sss_st4_fname = op.join(triux_path, 'triux_bmlhus_erm_st4_raw_sss.fif')
+tri_sss_ctc_fname = op.join(triux_path, 'triux_bmlhus_erm_ctc_raw_sss.fif')
+tri_sss_cal_fname = op.join(triux_path, 'triux_bmlhus_erm_cal_raw_sss.fif')
+tri_sss_ctc_cal_fname = op.join(
+    triux_path, 'triux_bmlhus_erm_ctc_cal_raw_sss.fif')
+tri_sss_ctc_cal_reg_in_fname = op.join(
+    triux_path, 'triux_bmlhus_erm_ctc_cal_regIn_raw_sss.fif')
+tri_ctc_fname = op.join(triux_path, 'ct_sparse_BMLHUS.fif')
+tri_cal_fname = op.join(triux_path, 'sss_cal_BMLHUS.dat')
+
 io_dir = op.join(op.dirname(__file__), '..', '..', 'io')
 fname_ctf_raw = op.join(io_dir, 'tests', 'data', 'test_ctf_comp_raw.fif')
 
@@ -95,20 +110,26 @@ bads = ['MEG0912', 'MEG1722', 'MEG2213', 'MEG0132', 'MEG1312', 'MEG0432',
 
 
 def _assert_n_free(raw_sss, lower, upper=None):
-    """Helper to check the DOF"""
+    """Check the DOF."""
     upper = lower if upper is None else upper
     n_free = raw_sss.info['proc_history'][0]['max_info']['sss_info']['nfree']
     assert_true(lower <= n_free <= upper,
                 'nfree fail: %s <= %s <= %s' % (lower, n_free, upper))
 
 
+def read_crop(fname, lims=(0, None)):
+    """Read and crop."""
+    return read_raw_fif(fname, allow_maxshield='yes',
+                        add_eeg_ref=False).crop(*lims)
+
+
 @slow_test
 @testing.requires_testing_data
 def test_movement_compensation():
-    """Test movement compensation"""
+    """Test movement compensation."""
     temp_dir = _TempDir()
     lims = (0, 4, False)
-    raw = Raw(raw_fname, allow_maxshield='yes', preload=True).crop(*lims)
+    raw = read_crop(raw_fname, lims).load_data()
     head_pos = read_head_pos(pos_fname)
 
     #
@@ -116,20 +137,20 @@ def test_movement_compensation():
     #
     raw_sss = maxwell_filter(raw, head_pos=head_pos, origin=mf_head_origin,
                              regularize=None, bad_condition='ignore')
-    assert_meg_snr(raw_sss, Raw(sss_movecomp_fname).crop(*lims),
+    assert_meg_snr(raw_sss, read_crop(sss_movecomp_fname, lims),
                    4.6, 12.4, chpi_med_tol=58)
     # IO
     temp_fname = op.join(temp_dir, 'test_raw_sss.fif')
     raw_sss.save(temp_fname)
-    raw_sss = Raw(temp_fname)
-    assert_meg_snr(raw_sss, Raw(sss_movecomp_fname).crop(*lims),
+    raw_sss = read_crop(temp_fname)
+    assert_meg_snr(raw_sss, read_crop(sss_movecomp_fname, lims),
                    4.6, 12.4, chpi_med_tol=58)
 
     #
     # Movement compensation,    regularization, no tSSS
     #
     raw_sss = maxwell_filter(raw, head_pos=head_pos, origin=mf_head_origin)
-    assert_meg_snr(raw_sss, Raw(sss_movecomp_reg_in_fname).crop(*lims),
+    assert_meg_snr(raw_sss, read_crop(sss_movecomp_reg_in_fname, lims),
                    0.5, 1.9, chpi_med_tol=121)
 
     #
@@ -143,25 +164,25 @@ def test_movement_compensation():
     assert_equal(len(w), 1)
     assert_true('is untested' in str(w[0].message))
     # Neither match is particularly good because our algorithm actually differs
-    assert_meg_snr(raw_sss_mv, Raw(sss_movecomp_reg_in_st4s_fname).crop(*lims),
+    assert_meg_snr(raw_sss_mv, read_crop(sss_movecomp_reg_in_st4s_fname, lims),
                    0.6, 1.3)
     tSSS_fname = op.join(sss_path, 'test_move_anon_st4s_raw_sss.fif')
-    assert_meg_snr(raw_sss_mv, Raw(tSSS_fname).crop(*lims),
+    assert_meg_snr(raw_sss_mv, read_crop(tSSS_fname, lims),
                    0.6, 1.0, chpi_med_tol=None)
-    assert_meg_snr(Raw(sss_movecomp_reg_in_st4s_fname), Raw(tSSS_fname),
-                   0.8, 1.0, chpi_med_tol=None)
+    assert_meg_snr(read_crop(sss_movecomp_reg_in_st4s_fname),
+                   read_crop(tSSS_fname), 0.8, 1.0, chpi_med_tol=None)
 
     #
     # Movement compensation,    regularization,    tSSS at the beginning
     #
     raw_sss_mc = maxwell_filter(raw_nohpi, head_pos=head_pos, st_duration=4.,
                                 origin=mf_head_origin)
-    assert_meg_snr(raw_sss_mc, Raw(tSSS_fname).crop(*lims),
+    assert_meg_snr(raw_sss_mc, read_crop(tSSS_fname, lims),
                    0.6, 1.0, chpi_med_tol=None)
     assert_meg_snr(raw_sss_mc, raw_sss_mv, 0.6, 1.4)
 
     # some degenerate cases
-    raw_erm = Raw(erm_fname, allow_maxshield='yes')
+    raw_erm = read_crop(erm_fname)
     assert_raises(ValueError, maxwell_filter, raw_erm, coord_frame='meg',
                   head_pos=head_pos)  # can't do ERM file
     assert_raises(ValueError, maxwell_filter, raw,
@@ -171,7 +192,15 @@ def test_movement_compensation():
     head_pos_bad = head_pos.copy()
     head_pos_bad[0, 0] = raw.first_samp / raw.info['sfreq'] - 1e-2
     assert_raises(ValueError, maxwell_filter, raw, head_pos=head_pos_bad)
+
+    head_pos_bad = head_pos.copy()
+    head_pos_bad[0, 4] = 1.  # off by more than 1 m
+    with warnings.catch_warnings(record=True) as w:
+        maxwell_filter(raw, head_pos=head_pos_bad, bad_condition='ignore')
+    assert_true(any('greater than 1 m' in str(ww.message) for ww in w))
+
     # make sure numerical error doesn't screw it up, though
+    head_pos_bad = head_pos.copy()
     head_pos_bad[0, 0] = raw.first_samp / raw.info['sfreq'] - 5e-4
     raw_sss_tweak = maxwell_filter(raw, head_pos=head_pos_bad,
                                    origin=mf_head_origin)
@@ -180,8 +209,7 @@ def test_movement_compensation():
 
 @slow_test
 def test_other_systems():
-    """Test Maxwell filtering on KIT, BTI, and CTF files
-    """
+    """Test Maxwell filtering on KIT, BTI, and CTF files."""
     # KIT
     kit_dir = op.join(io_dir, 'kit', 'tests', 'data')
     sqd_path = op.join(kit_dir, 'test.sqd')
@@ -193,6 +221,9 @@ def test_other_systems():
         assert_raises(RuntimeError, maxwell_filter, raw_kit)
     raw_sss = maxwell_filter(raw_kit, origin=(0., 0., 0.04), ignore_ref=True)
     _assert_n_free(raw_sss, 65, 65)
+    raw_sss_auto = maxwell_filter(raw_kit, origin=(0., 0., 0.04),
+                                  ignore_ref=True, mag_scale='auto')
+    assert_allclose(raw_sss._data, raw_sss_auto._data)
     # XXX this KIT origin fit is terrible! Eventually we should get a
     # corrected HSP file with proper coverage
     with warnings.catch_warnings(record=True):
@@ -232,22 +263,33 @@ def test_other_systems():
     bti_hs = op.join(bti_dir, 'test_hs_linux')
     with warnings.catch_warnings(record=True):  # weght table
         raw_bti = read_raw_bti(bti_pdf, bti_config, bti_hs, preload=False)
+    picks = pick_types(raw_bti.info, meg='mag', exclude=())
+    power = np.sqrt(np.sum(raw_bti[picks][0] ** 2))
     raw_sss = maxwell_filter(raw_bti)
     _assert_n_free(raw_sss, 70)
+    _assert_shielding(raw_sss, power, 0.5)
+    raw_sss_auto = maxwell_filter(raw_bti, mag_scale='auto', verbose=True)
+    _assert_shielding(raw_sss_auto, power, 0.7)
 
     # CTF
-    raw_ctf = Raw(fname_ctf_raw, compensation=2)
+    raw_ctf = read_crop(fname_ctf_raw)
+    assert_equal(raw_ctf.compensation_grade, 3)
     assert_raises(RuntimeError, maxwell_filter, raw_ctf)  # compensated
-    raw_ctf = Raw(fname_ctf_raw)
+    raw_ctf.apply_gradient_compensation(0)
     assert_raises(ValueError, maxwell_filter, raw_ctf)  # cannot fit headshape
     raw_sss = maxwell_filter(raw_ctf, origin=(0., 0., 0.04))
     _assert_n_free(raw_sss, 68)
+    _assert_shielding(raw_sss, raw_ctf, 1.8)
     raw_sss = maxwell_filter(raw_ctf, origin=(0., 0., 0.04), ignore_ref=True)
     _assert_n_free(raw_sss, 70)
+    _assert_shielding(raw_sss, raw_ctf, 12)
+    raw_sss_auto = maxwell_filter(raw_ctf, origin=(0., 0., 0.04),
+                                  ignore_ref=True, mag_scale='auto')
+    assert_allclose(raw_sss._data, raw_sss_auto._data)
 
 
 def test_spherical_harmonics():
-    """Test spherical harmonic functions"""
+    """Test spherical harmonic functions."""
     from scipy.special import sph_harm
     az, pol = np.meshgrid(np.linspace(0, 2 * np.pi, 30),
                           np.linspace(0, np.pi, 20))
@@ -267,7 +309,7 @@ def test_spherical_harmonics():
 
 
 def test_spherical_conversions():
-    """Test spherical harmonic conversions"""
+    """Test spherical harmonic conversions."""
     # Test our real<->complex conversion functions
     az, pol = np.meshgrid(np.linspace(0, 2 * np.pi, 30),
                           np.linspace(0, np.pi, 20))
@@ -286,7 +328,7 @@ def test_spherical_conversions():
 
 @testing.requires_testing_data
 def test_multipolar_bases():
-    """Test multipolar moment basis calculation using sensor information"""
+    """Test multipolar moment basis calculation using sensor information."""
     from scipy.io import loadmat
     # Test our basis calculations
     info = read_info(raw_fname)
@@ -346,11 +388,11 @@ def test_multipolar_bases():
 
 @testing.requires_testing_data
 def test_basic():
-    """Test Maxwell filter basic version"""
+    """Test Maxwell filter basic version."""
     # Load testing data (raw, SSS std origin, SSS non-standard origin)
-    raw = Raw(raw_fname, allow_maxshield='yes').crop(0., 1., copy=False)
-    raw_err = Raw(raw_fname, proj=True, allow_maxshield='yes')
-    raw_erm = Raw(erm_fname, allow_maxshield='yes')
+    raw = read_crop(raw_fname, (0., 1.))
+    raw_err = read_crop(raw_fname).apply_proj()
+    raw_erm = read_crop(erm_fname)
     assert_raises(RuntimeError, maxwell_filter, raw_err)
     assert_raises(TypeError, maxwell_filter, 1.)  # not a raw
     assert_raises(ValueError, maxwell_filter, raw, int_order=20)  # too many
@@ -368,7 +410,7 @@ def test_basic():
                              bad_condition='ignore')
     assert_equal(len(raw_sss.info['projs']), 1)  # avg EEG
     assert_equal(raw_sss.info['projs'][0]['desc'], 'Average EEG reference')
-    assert_meg_snr(raw_sss, Raw(sss_std_fname), 200., 1000.)
+    assert_meg_snr(raw_sss, read_crop(sss_std_fname), 200., 1000.)
     py_cal = raw_sss.info['proc_history'][0]['max_info']['sss_cal']
     assert_equal(len(py_cal), 0)
     py_ctc = raw_sss.info['proc_history'][0]['max_info']['sss_ctc']
@@ -380,10 +422,10 @@ def test_basic():
     # Test SSS computation at non-standard head origin
     raw_sss = maxwell_filter(raw, origin=[0., 0.02, 0.02], regularize=None,
                              bad_condition='ignore')
-    assert_meg_snr(raw_sss, Raw(sss_nonstd_fname), 250., 700.)
+    assert_meg_snr(raw_sss, read_crop(sss_nonstd_fname), 250., 700.)
 
     # Test SSS computation at device origin
-    sss_erm_std = Raw(sss_erm_std_fname)
+    sss_erm_std = read_crop(sss_erm_std_fname)
     raw_sss = maxwell_filter(raw_erm, coord_frame='meg',
                              origin=mf_meg_origin, regularize=None,
                              bad_condition='ignore')
@@ -399,18 +441,15 @@ def test_basic():
                  proc_history._get_sss_rank(sss_info))
 
     # Degenerate cases
-    raw_bad = raw.copy()
-    raw_bad.comp = True
-    assert_raises(RuntimeError, maxwell_filter, raw_bad)
-    del raw_bad
     assert_raises(ValueError, maxwell_filter, raw, coord_frame='foo')
     assert_raises(ValueError, maxwell_filter, raw, origin='foo')
     assert_raises(ValueError, maxwell_filter, raw, origin=[0] * 4)
+    assert_raises(ValueError, maxwell_filter, raw, mag_scale='foo')
 
 
 @testing.requires_testing_data
 def test_maxwell_filter_additional():
-    """Test processing of Maxwell filtered data"""
+    """Test processing of Maxwell filtered data."""
 
     # TODO: Future tests integrate with mne/io/tests/test_proc_history
 
@@ -422,7 +461,7 @@ def test_maxwell_filter_additional():
     raw_fname = op.join(data_path, 'SSS', file_name + '_raw.fif')
 
     # Use 2.0 seconds of data to get stable cov. estimate
-    raw = Raw(raw_fname, allow_maxshield='yes').crop(0., 2., copy=False)
+    raw = read_crop(raw_fname, (0., 2.))
 
     # Get MEG channels, compute Maxwell filtered data
     raw.load_data()
@@ -435,7 +474,7 @@ def test_maxwell_filter_additional():
     tempdir = _TempDir()
     test_outname = op.join(tempdir, 'test_raw_sss.fif')
     raw_sss.save(test_outname)
-    raw_sss_loaded = Raw(test_outname, preload=True)
+    raw_sss_loaded = read_crop(test_outname).load_data()
 
     # Some numerical imprecision since save uses 'single' fmt
     assert_allclose(raw_sss_loaded[:][0], raw_sss[:][0],
@@ -457,20 +496,20 @@ def test_maxwell_filter_additional():
 @slow_test
 @testing.requires_testing_data
 def test_bads_reconstruction():
-    """Test Maxwell filter reconstruction of bad channels"""
-    raw = Raw(raw_fname, allow_maxshield='yes').crop(0., 1.)
+    """Test Maxwell filter reconstruction of bad channels."""
+    raw = read_crop(raw_fname, (0., 1.))
     raw.info['bads'] = bads
     raw_sss = maxwell_filter(raw, origin=mf_head_origin, regularize=None,
                              bad_condition='ignore')
-    assert_meg_snr(raw_sss, Raw(sss_bad_recon_fname), 300.)
+    assert_meg_snr(raw_sss, read_crop(sss_bad_recon_fname), 300.)
 
 
 @requires_svd_convergence
 @testing.requires_testing_data
 def test_spatiotemporal_maxwell():
-    """Test Maxwell filter (tSSS) spatiotemporal processing"""
+    """Test Maxwell filter (tSSS) spatiotemporal processing."""
     # Load raw testing data
-    raw = Raw(raw_fname, allow_maxshield='yes')
+    raw = read_crop(raw_fname)
 
     # Test that window is less than length of data
     assert_raises(ValueError, maxwell_filter, raw, st_duration=1000.)
@@ -483,7 +522,7 @@ def test_spatiotemporal_maxwell():
         # Load tSSS data depending on st_duration and get data
         tSSS_fname = op.join(sss_path,
                              'test_move_anon_st%0ds_raw_sss.fif' % st_duration)
-        tsss_bench = Raw(tSSS_fname)
+        tsss_bench = read_crop(tSSS_fname)
         # Because Elekta's tSSS sometimes(!) lumps the tail window of data
         # onto the previous buffer if it's shorter than st_duration, we have to
         # crop the data here to compensate for Elekta's tSSS behavior.
@@ -522,10 +561,9 @@ def test_spatiotemporal_maxwell():
 @requires_svd_convergence
 @testing.requires_testing_data
 def test_spatiotemporal_only():
-    """Test tSSS-only processing"""
+    """Test tSSS-only processing."""
     # Load raw testing data
-    raw = Raw(raw_fname,
-              allow_maxshield='yes').crop(0, 2, copy=False).load_data()
+    raw = read_crop(raw_fname, (0, 2)).load_data()
     picks = pick_types(raw.info, meg='mag', exclude=())
     power = np.sqrt(np.sum(raw[picks][0] ** 2))
     # basics
@@ -574,11 +612,11 @@ def test_spatiotemporal_only():
 
 @testing.requires_testing_data
 def test_fine_calibration():
-    """Test Maxwell filter fine calibration"""
+    """Test Maxwell filter fine calibration."""
 
     # Load testing data (raw, SSS std origin, SSS non-standard origin)
-    raw = Raw(raw_fname, allow_maxshield='yes').crop(0., 1., copy=False)
-    sss_fine_cal = Raw(sss_fine_cal_fname)
+    raw = read_crop(raw_fname, (0., 1.))
+    sss_fine_cal = read_crop(sss_fine_cal_fname)
 
     # Test 1D SSS fine calibration
     raw_sss = maxwell_filter(raw, calibration=fine_cal_fname,
@@ -601,7 +639,7 @@ def test_fine_calibration():
                                 origin=mf_head_origin, regularize=None,
                                 bad_condition='ignore')
     assert_meg_snr(raw_sss_3D, sss_fine_cal, 1.0, 6.)
-    raw_ctf = Raw(fname_ctf_raw)
+    raw_ctf = read_crop(fname_ctf_raw).apply_gradient_compensation(0)
     assert_raises(RuntimeError, maxwell_filter, raw_ctf, origin=(0., 0., 0.04),
                   calibration=fine_cal_fname)
 
@@ -609,7 +647,7 @@ def test_fine_calibration():
 @slow_test
 @testing.requires_testing_data
 def test_regularization():
-    """Test Maxwell filter regularization"""
+    """Test Maxwell filter regularization."""
     # Load testing data (raw, SSS std origin, SSS non-standard origin)
     min_tols = (100., 2.6, 1.0)
     med_tols = (1000., 21.4, 3.7)
@@ -620,8 +658,8 @@ def test_regularization():
                   sss_samp_reg_in_fname)
     comp_tols = [0, 1, 4]
     for ii, rf in enumerate(raw_fnames):
-        raw = Raw(rf, allow_maxshield='yes').crop(0., 1.)
-        sss_reg_in = Raw(sss_fnames[ii])
+        raw = read_crop(rf, (0., 1.))
+        sss_reg_in = read_crop(sss_fnames[ii])
 
         # Test "in" regularization
         raw_sss = maxwell_filter(raw, coord_frame=coord_frames[ii],
@@ -629,27 +667,32 @@ def test_regularization():
         assert_meg_snr(raw_sss, sss_reg_in, min_tols[ii], med_tols[ii], msg=rf)
 
         # check components match
-        py_info = raw_sss.info['proc_history'][0]['max_info']['sss_info']
-        assert_true(py_info is not None)
-        assert_true(len(py_info) > 0)
-        mf_info = sss_reg_in.info['proc_history'][0]['max_info']['sss_info']
-        n_in = None
-        for inf in py_info, mf_info:
-            if n_in is None:
-                n_in = _get_n_moments(inf['in_order'])
-            else:
-                assert_equal(n_in, _get_n_moments(inf['in_order']))
-            assert_equal(inf['components'][:n_in].sum(), inf['nfree'])
-        assert_allclose(py_info['nfree'], mf_info['nfree'],
-                        atol=comp_tols[ii], err_msg=rf)
+        _check_reg_match(raw_sss, sss_reg_in, comp_tols[ii])
+
+
+def _check_reg_match(sss_py, sss_mf, comp_tol):
+    """Helper to check regularization."""
+    info_py = sss_py.info['proc_history'][0]['max_info']['sss_info']
+    assert_true(info_py is not None)
+    assert_true(len(info_py) > 0)
+    info_mf = sss_mf.info['proc_history'][0]['max_info']['sss_info']
+    n_in = None
+    for inf in (info_py, info_mf):
+        if n_in is None:
+            n_in = _get_n_moments(inf['in_order'])
+        else:
+            assert_equal(n_in, _get_n_moments(inf['in_order']))
+        assert_equal(inf['components'][:n_in].sum(), inf['nfree'])
+    assert_allclose(info_py['nfree'], info_mf['nfree'],
+                    atol=comp_tol, err_msg=sss_py._filenames[0])
 
 
 @testing.requires_testing_data
 def test_cross_talk():
-    """Test Maxwell filter cross-talk cancellation"""
-    raw = Raw(raw_fname, allow_maxshield='yes').crop(0., 1., copy=False)
+    """Test Maxwell filter cross-talk cancellation."""
+    raw = read_crop(raw_fname, (0., 1.))
     raw.info['bads'] = bads
-    sss_ctc = Raw(sss_ctc_fname)
+    sss_ctc = read_crop(sss_ctc_fname)
     raw_sss = maxwell_filter(raw, cross_talk=ctc_fname,
                              origin=mf_head_origin, regularize=None,
                              bad_condition='ignore')
@@ -661,7 +704,7 @@ def test_cross_talk():
     mf_ctc = sss_ctc.info['proc_history'][0]['max_info']['sss_ctc']
     del mf_ctc['block_id']  # we don't write this
     assert_equal(object_diff(py_ctc, mf_ctc), '')
-    raw_ctf = Raw(fname_ctf_raw)
+    raw_ctf = read_crop(fname_ctf_raw).apply_gradient_compensation(0)
     assert_raises(ValueError, maxwell_filter, raw_ctf)  # cannot fit headshape
     raw_sss = maxwell_filter(raw_ctf, origin=(0., 0., 0.04))
     _assert_n_free(raw_sss, 68)
@@ -681,13 +724,13 @@ def test_cross_talk():
 
 @testing.requires_testing_data
 def test_head_translation():
-    """Test Maxwell filter head translation"""
-    raw = Raw(raw_fname, allow_maxshield='yes').crop(0., 1., copy=False)
+    """Test Maxwell filter head translation."""
+    raw = read_crop(raw_fname, (0., 1.))
     # First try with an unchanged destination
     raw_sss = maxwell_filter(raw, destination=raw_fname,
                              origin=mf_head_origin, regularize=None,
                              bad_condition='ignore')
-    assert_meg_snr(raw_sss, Raw(sss_std_fname).crop(0., 1.), 200.)
+    assert_meg_snr(raw_sss, read_crop(sss_std_fname, (0., 1.)), 200.)
     # Now with default
     with warnings.catch_warnings(record=True):
         with catch_logging() as log:
@@ -695,7 +738,7 @@ def test_head_translation():
                                      origin=mf_head_origin, regularize=None,
                                      bad_condition='ignore', verbose='warning')
     assert_true('over 25 mm' in log.getvalue())
-    assert_meg_snr(raw_sss, Raw(sss_trans_default_fname), 125.)
+    assert_meg_snr(raw_sss, read_crop(sss_trans_default_fname), 125.)
     destination = np.eye(4)
     destination[2, 3] = 0.04
     assert_allclose(raw_sss.info['dev_head_t']['trans'], destination)
@@ -706,7 +749,7 @@ def test_head_translation():
                                      origin=mf_head_origin, regularize=None,
                                      bad_condition='ignore', verbose='warning')
     assert_true('= 25.6 mm' in log.getvalue())
-    assert_meg_snr(raw_sss, Raw(sss_trans_sample_fname), 350.)
+    assert_meg_snr(raw_sss, read_crop(sss_trans_sample_fname), 350.)
     assert_allclose(raw_sss.info['dev_head_t']['trans'],
                     read_info(sample_fname)['dev_head_t']['trans'])
     # Degenerate cases
@@ -720,8 +763,12 @@ def test_head_translation():
 # http://ieeexplore.ieee.org/xpl/articleDetails.jsp?arnumber=1495874
 
 def _assert_shielding(raw_sss, erm_power, shielding_factor, meg='mag'):
-    """Helper to assert a minimum shielding factor using empty-room power"""
-    picks = pick_types(raw_sss.info, meg=meg)
+    """Helper to assert a minimum shielding factor using empty-room power."""
+    picks = pick_types(raw_sss.info, meg=meg, ref_meg=False)
+    if isinstance(erm_power, _BaseRaw):
+        picks_erm = pick_types(raw_sss.info, meg=meg, ref_meg=False)
+        assert_allclose(picks, picks_erm)
+        erm_power = np.sqrt((erm_power[picks_erm][0] ** 2).sum())
     sss_power = raw_sss[picks][0].ravel()
     sss_power = np.sqrt(np.sum(sss_power * sss_power))
     factor = erm_power / sss_power
@@ -729,30 +776,48 @@ def _assert_shielding(raw_sss, erm_power, shielding_factor, meg='mag'):
                 'Shielding factor %0.3f < %0.3f' % (factor, shielding_factor))
 
 
+@buggy_mkl_svd
 @slow_test
 @requires_svd_convergence
 @testing.requires_testing_data
 def test_shielding_factor():
-    """Test Maxwell filter shielding factor using empty room"""
-    raw_erm = Raw(erm_fname, allow_maxshield='yes', preload=True)
+    """Test Maxwell filter shielding factor using empty room."""
+    raw_erm = read_crop(erm_fname).load_data()
     picks = pick_types(raw_erm.info, meg='mag')
     erm_power = raw_erm[picks][0]
     erm_power = np.sqrt(np.sum(erm_power * erm_power))
+    erm_power_grad = raw_erm[pick_types(raw_erm.info, meg='grad')][0]
+    erm_power_grad = np.sqrt(np.sum(erm_power * erm_power))
 
     # Vanilla SSS (second value would be for meg=True instead of meg='mag')
-    _assert_shielding(Raw(sss_erm_std_fname), erm_power, 10)  # 1.5)
+    _assert_shielding(read_crop(sss_erm_std_fname), erm_power, 10)  # 1.5)
     raw_sss = maxwell_filter(raw_erm, coord_frame='meg', regularize=None)
     _assert_shielding(raw_sss, erm_power, 12)  # 1.5)
+    _assert_shielding(raw_sss, erm_power_grad, 0.45, 'grad')  # 1.5)
+
+    # Using different mag_scale values
+    raw_sss = maxwell_filter(raw_erm, coord_frame='meg', regularize=None,
+                             mag_scale='auto')
+    _assert_shielding(raw_sss, erm_power, 12)
+    _assert_shielding(raw_sss, erm_power_grad, 0.48, 'grad')
+    raw_sss = maxwell_filter(raw_erm, coord_frame='meg', regularize=None,
+                             mag_scale=1.)  # not a good choice
+    _assert_shielding(raw_sss, erm_power, 7.3)
+    _assert_shielding(raw_sss, erm_power_grad, 0.2, 'grad')
+    raw_sss = maxwell_filter(raw_erm, coord_frame='meg', regularize=None,
+                             mag_scale=1000., bad_condition='ignore')
+    _assert_shielding(raw_sss, erm_power, 4.0)
+    _assert_shielding(raw_sss, erm_power_grad, 0.1, 'grad')
 
     # Fine cal
-    _assert_shielding(Raw(sss_erm_fine_cal_fname), erm_power, 12)  # 2.0)
+    _assert_shielding(read_crop(sss_erm_fine_cal_fname), erm_power, 12)  # 2.0)
     raw_sss = maxwell_filter(raw_erm, coord_frame='meg', regularize=None,
                              origin=mf_meg_origin,
                              calibration=fine_cal_fname)
     _assert_shielding(raw_sss, erm_power, 12)  # 2.0)
 
     # Crosstalk
-    _assert_shielding(Raw(sss_erm_ctc_fname), erm_power, 12)  # 2.1)
+    _assert_shielding(read_crop(sss_erm_ctc_fname), erm_power, 12)  # 2.1)
     raw_sss = maxwell_filter(raw_erm, coord_frame='meg', regularize=None,
                              origin=mf_meg_origin,
                              cross_talk=ctc_fname)
@@ -766,7 +831,7 @@ def test_shielding_factor():
     _assert_shielding(raw_sss, erm_power, 13)  # 2.2)
 
     # tSSS
-    _assert_shielding(Raw(sss_erm_st_fname), erm_power, 37)  # 5.8)
+    _assert_shielding(read_crop(sss_erm_st_fname), erm_power, 37)  # 5.8)
     raw_sss = maxwell_filter(raw_erm, coord_frame='meg', regularize=None,
                              origin=mf_meg_origin, st_duration=1.)
     _assert_shielding(raw_sss, erm_power, 37)  # 5.8)
@@ -784,7 +849,7 @@ def test_shielding_factor():
     _assert_shielding(raw_sss, erm_power, 38)  # 5.98)
 
     # Fine cal + Crosstalk + tSSS
-    _assert_shielding(Raw(sss_erm_st1FineCalCrossTalk_fname),
+    _assert_shielding(read_crop(sss_erm_st1FineCalCrossTalk_fname),
                       erm_power, 39)  # 6.07)
     raw_sss = maxwell_filter(raw_erm, coord_frame='meg', regularize=None,
                              calibration=fine_cal_fname, origin=mf_meg_origin,
@@ -792,8 +857,8 @@ def test_shielding_factor():
     _assert_shielding(raw_sss, erm_power, 39)  # 6.05)
 
     # Fine cal + Crosstalk + tSSS + Reg-in
-    _assert_shielding(Raw(sss_erm_st1FineCalCrossTalkRegIn_fname), erm_power,
-                      57)  # 6.97)
+    _assert_shielding(read_crop(sss_erm_st1FineCalCrossTalkRegIn_fname),
+                      erm_power, 57)  # 6.97)
     raw_sss = maxwell_filter(raw_erm, calibration=fine_cal_fname,
                              cross_talk=ctc_fname, st_duration=1.,
                              origin=mf_meg_origin,
@@ -803,6 +868,13 @@ def test_shielding_factor():
                              cross_talk=ctc_fname, st_duration=1.,
                              coord_frame='meg', regularize='in')
     _assert_shielding(raw_sss, erm_power, 58)  # 7.0)
+    _assert_shielding(raw_sss, erm_power_grad, 1.6, 'grad')
+    raw_sss = maxwell_filter(raw_erm, calibration=fine_cal_fname,
+                             cross_talk=ctc_fname, st_duration=1.,
+                             coord_frame='meg', regularize='in',
+                             mag_scale='auto')
+    _assert_shielding(raw_sss, erm_power, 51)
+    _assert_shielding(raw_sss, erm_power_grad, 1.5, 'grad')
     raw_sss = maxwell_filter(raw_erm, calibration=fine_cal_fname_3d,
                              cross_talk=ctc_fname, st_duration=1.,
                              coord_frame='meg', regularize='in')
@@ -827,7 +899,7 @@ def test_shielding_factor():
 @requires_svd_convergence
 @testing.requires_testing_data
 def test_all():
-    """Test maxwell filter using all options"""
+    """Test maxwell filter using all options."""
     raw_fnames = (raw_fname, raw_fname, erm_fname, sample_fname)
     sss_fnames = (sss_st1FineCalCrossTalkRegIn_fname,
                   sss_st1FineCalCrossTalkRegInTransSample_fname,
@@ -840,7 +912,7 @@ def test_all():
     coord_frames = ('head', 'head', 'meg', 'head')
     ctcs = (ctc_fname, ctc_fname, ctc_fname, ctc_mgh_fname)
     mins = (3.5, 3.5, 1.2, 0.9)
-    meds = (10.9, 10.4, 3.2, 6.)
+    meds = (10.8, 10.4, 3.2, 6.)
     st_durs = (1., 1., 1., None)
     destinations = (None, sample_fname, None, None)
     origins = (mf_head_origin,
@@ -848,13 +920,55 @@ def test_all():
                mf_meg_origin,
                mf_head_origin)
     for ii, rf in enumerate(raw_fnames):
-        raw = Raw(rf, allow_maxshield='yes').crop(0., 1.)
+        raw = read_crop(rf, (0., 1.))
         with warnings.catch_warnings(record=True):  # head fit off-center
             sss_py = maxwell_filter(
                 raw, calibration=fine_cals[ii], cross_talk=ctcs[ii],
                 st_duration=st_durs[ii], coord_frame=coord_frames[ii],
                 destination=destinations[ii], origin=origins[ii])
-        sss_mf = Raw(sss_fnames[ii])
+        sss_mf = read_crop(sss_fnames[ii])
         assert_meg_snr(sss_py, sss_mf, mins[ii], meds[ii], msg=rf)
 
+
+@slow_test
+@requires_svd_convergence
+@testing.requires_testing_data
+def test_triux():
+    """Test TRIUX system support."""
+    raw = read_crop(tri_fname, (0, 0.999))
+    raw.fix_mag_coil_types()
+    # standard
+    sss_py = maxwell_filter(raw, coord_frame='meg', regularize=None)
+    assert_meg_snr(sss_py, read_crop(tri_sss_fname), 37, 700)
+    # cross-talk
+    sss_py = maxwell_filter(raw, coord_frame='meg', regularize=None,
+                            cross_talk=tri_ctc_fname)
+    assert_meg_snr(sss_py, read_crop(tri_sss_ctc_fname), 35, 700)
+    # fine cal
+    sss_py = maxwell_filter(raw, coord_frame='meg', regularize=None,
+                            calibration=tri_cal_fname)
+    assert_meg_snr(sss_py, read_crop(tri_sss_cal_fname), 31, 360)
+    # ctc+cal
+    sss_py = maxwell_filter(raw, coord_frame='meg', regularize=None,
+                            calibration=tri_cal_fname,
+                            cross_talk=tri_ctc_fname)
+    assert_meg_snr(sss_py, read_crop(tri_sss_ctc_cal_fname), 31, 350)
+    # regularization
+    sss_py = maxwell_filter(raw, coord_frame='meg', regularize='in')
+    sss_mf = read_crop(tri_sss_reg_fname)
+    assert_meg_snr(sss_py, sss_mf, 0.6, 9)
+    _check_reg_match(sss_py, sss_mf, 1)
+    # all three
+    sss_py = maxwell_filter(raw, coord_frame='meg', regularize='in',
+                            calibration=tri_cal_fname,
+                            cross_talk=tri_ctc_fname)
+    sss_mf = read_crop(tri_sss_ctc_cal_reg_in_fname)
+    assert_meg_snr(sss_py, sss_mf, 0.6, 9)
+    _check_reg_match(sss_py, sss_mf, 1)
+    # tSSS
+    raw = read_crop(tri_fname).fix_mag_coil_types()
+    sss_py = maxwell_filter(raw, coord_frame='meg', regularize=None,
+                            st_duration=4., verbose=True)
+    assert_meg_snr(sss_py, read_crop(tri_sss_st4_fname), 700., 1600)
+
 run_tests_if_main()
