@@ -10,19 +10,20 @@ from copy import deepcopy
 
 import numpy as np
 from numpy.testing import assert_allclose, assert_array_equal
-from nose.tools import assert_true, assert_raises
+from nose.tools import assert_true, assert_raises, assert_equal
 
 from mne import (read_source_spaces, pick_types, read_trans, read_cov,
-                 make_sphere_model, create_info, setup_volume_source_space)
+                 make_sphere_model, create_info, setup_volume_source_space,
+                 find_events, Epochs, fit_dipole, transform_surface_to,
+                 make_ad_hoc_cov, SourceEstimate, setup_source_space)
 from mne.chpi import (_calculate_chpi_positions, read_head_pos,
                       _get_hpi_info, head_pos_to_trans_rot_t)
 from mne.tests.test_chpi import _compare_positions
 from mne.datasets import testing
 from mne.simulation import simulate_sparse_stc, simulate_raw
-from mne.io import Raw, RawArray
+from mne.io import read_raw_fif, RawArray
 from mne.time_frequency import psd_welch
 from mne.utils import _TempDir, run_tests_if_main, requires_version, slow_test
-from mne.fixes import isclose
 
 
 warnings.simplefilter('always')
@@ -33,7 +34,8 @@ cov_fname = op.join(data_path, 'MEG', 'sample',
                     'sample_audvis_trunc-cov.fif')
 trans_fname = op.join(data_path, 'MEG', 'sample',
                       'sample_audvis_trunc-trans.fif')
-bem_path = op.join(data_path, 'subjects', 'sample', 'bem')
+subjects_dir = op.join(data_path, 'subjects')
+bem_path = op.join(subjects_dir, 'sample', 'bem')
 src_fname = op.join(bem_path, 'sample-oct-2-src.fif')
 bem_fname = op.join(bem_path, 'sample-320-320-320-bem-sol.fif')
 
@@ -42,7 +44,7 @@ pos_fname = op.join(data_path, 'SSS', 'test_move_anon_raw_subsampled.pos')
 
 
 def _make_stc(raw, src):
-    """Helper to make a STC"""
+    """Helper to make a STC."""
     seed = 42
     sfreq = raw.info['sfreq']  # Hz
     tstep = 1. / sfreq
@@ -53,13 +55,15 @@ def _make_stc(raw, src):
 
 
 def _get_data():
-    """Helper to get some starting data"""
+    """Helper to get some starting data."""
     # raw with ECG channel
-    raw = Raw(raw_fname).crop(0., 5.0, copy=False).load_data()
+    raw = read_raw_fif(raw_fname, add_eeg_ref=False)
+    raw.crop(0., 5.0, copy=False).load_data()
     data_picks = pick_types(raw.info, meg=True, eeg=True)
     other_picks = pick_types(raw.info, meg=False, stim=True, eog=True)
     picks = np.sort(np.concatenate((data_picks[::16], other_picks)))
     raw = raw.pick_channels([raw.ch_names[p] for p in picks])
+    raw.info.normalize_proj()
     ecg = RawArray(np.zeros((1, len(raw.times))),
                    create_info(['ECG 063'], raw.info['sfreq'], 'ecg'))
     for key in ('dev_head_t', 'buffer_size_sec', 'highpass', 'lowpass',
@@ -76,7 +80,7 @@ def _get_data():
 
 @testing.requires_testing_data
 def test_simulate_raw_sphere():
-    """Test simulation of raw data with sphere model"""
+    """Test simulation of raw data with sphere model."""
     seed = 42
     raw, src, stc, trans, sphere = _get_data()
     assert_true(len(pick_types(raw.info, meg=False, ecg=True)) == 1)
@@ -107,7 +111,8 @@ def test_simulate_raw_sphere():
     test_outname = op.join(tempdir, 'sim_test_raw.fif')
     raw_sim.save(test_outname)
 
-    raw_sim_loaded = Raw(test_outname, preload=True, proj=False)
+    raw_sim_loaded = read_raw_fif(test_outname, preload=True, proj=False,
+                                  add_eeg_ref=False)
     assert_allclose(raw_sim_loaded[:][0], raw_sim[:][0], rtol=1e-6, atol=1e-20)
     del raw_sim, raw_sim_2
     # with no cov (no noise) but with artifacts, most time periods should match
@@ -122,11 +127,11 @@ def test_simulate_raw_sphere():
         picks = np.arange(len(raw.ch_names))
         diff_picks = pick_types(raw.info, meg=False, ecg=ecg, eog=eog)
         these_picks = np.setdiff1d(picks, diff_picks)
-        close = isclose(raw_sim_3[these_picks][0],
-                        raw_sim_4[these_picks][0], atol=1e-20)
+        close = np.isclose(raw_sim_3[these_picks][0],
+                           raw_sim_4[these_picks][0], atol=1e-20)
         assert_true(np.mean(close) > 0.7)
-        far = ~isclose(raw_sim_3[diff_picks][0],
-                       raw_sim_4[diff_picks][0], atol=1e-20)
+        far = ~np.isclose(raw_sim_3[diff_picks][0],
+                          raw_sim_4[diff_picks][0], atol=1e-20)
         assert_true(np.mean(far) > 0.99)
     del raw_sim_3, raw_sim_4
 
@@ -191,13 +196,15 @@ def test_simulate_raw_sphere():
 
 @testing.requires_testing_data
 def test_simulate_raw_bem():
-    """Test simulation of raw data with BEM"""
-    seed = 42
+    """Test simulation of raw data with BEM."""
     raw, src, stc, trans, sphere = _get_data()
-    raw_sim_sph = simulate_raw(raw, stc, trans, src, sphere, cov=None,
-                               ecg=True, blink=True, random_state=seed)
+    src = setup_source_space('sample', None, 'oct1', subjects_dir=subjects_dir)
+    # use different / more complete STC here
+    vertices = [s['vertno'] for s in src]
+    stc = SourceEstimate(np.eye(sum(len(v) for v in vertices)), vertices,
+                         0, 1. / raw.info['sfreq'])
+    raw_sim_sph = simulate_raw(raw, stc, trans, src, sphere, cov=None)
     raw_sim_bem = simulate_raw(raw, stc, trans, src, bem_fname, cov=None,
-                               ecg=True, blink=True, random_state=seed,
                                n_jobs=2)
     # some components (especially radial) might not match that well,
     # so just make sure that most components have high correlation
@@ -206,7 +213,25 @@ def test_simulate_raw_bem():
     n_ch = len(picks)
     corr = np.corrcoef(raw_sim_sph[picks][0], raw_sim_bem[picks][0])
     assert_array_equal(corr.shape, (2 * n_ch, 2 * n_ch))
-    assert_true(np.median(np.diag(corr[:n_ch, -n_ch:])) > 0.9)
+    assert_true(np.median(np.diag(corr[:n_ch, -n_ch:])) > 0.65)
+    # do some round-trip localization
+    for s in src:
+        transform_surface_to(s, 'head', trans)
+    locs = np.concatenate([s['rr'][s['vertno']] for s in src])
+    tmax = (len(locs) - 1) / raw.info['sfreq']
+    cov = make_ad_hoc_cov(raw.info)
+    # The tolerance for the BEM is surprisingly high (28) but I get the same
+    # result when using MNE-C and Xfit, even when using a proper 5120 BEM :(
+    for use_raw, bem, tol in ((raw_sim_sph, sphere, 1),
+                              (raw_sim_bem, bem_fname, 28)):
+        events = find_events(use_raw, 'STI 014')
+        assert_equal(len(locs), 12)  # oct1 count
+        evoked = Epochs(use_raw, events, 1, 0, tmax, baseline=None,
+                        add_eeg_ref=False).average()
+        assert_equal(len(evoked.times), len(locs))
+        fits = fit_dipole(evoked, cov, bem, trans, min_dist=1.)[0].pos
+        diffs = np.sqrt(np.sum((locs - fits) ** 2, axis=-1)) * 1000
+        assert_true(np.median(diffs) < tol)
 
 
 @slow_test
@@ -214,8 +239,9 @@ def test_simulate_raw_bem():
 @requires_version('scipy', '0.12')
 @testing.requires_testing_data
 def test_simulate_raw_chpi():
-    """Test simulation of raw data with cHPI"""
-    raw = Raw(raw_chpi_fname, allow_maxshield='yes')
+    """Test simulation of raw data with cHPI."""
+    raw = read_raw_fif(raw_chpi_fname, allow_maxshield='yes',
+                       add_eeg_ref=False)
     sphere = make_sphere_model('auto', 'auto', raw.info)
     # make sparse spherical source space
     sphere_vol = tuple(sphere['r0'] * 1000.) + (sphere.radius * 1000.,)
