@@ -2,7 +2,7 @@ import os.path as op
 
 import numpy as np
 from numpy.testing import assert_array_almost_equal, assert_array_equal
-from nose.tools import assert_true
+from nose.tools import assert_true, assert_raises, assert_equal
 
 from mne.datasets import testing
 from mne import read_label, read_forward_solution, pick_types_forward
@@ -17,6 +17,7 @@ fname_fwd = op.join(data_path, 'MEG', 'sample',
 label_names = ['Aud-lh', 'Aud-rh', 'Vis-rh']
 
 label_names_single_hemi = ['Aud-rh', 'Vis-rh']
+subjects_dir = op.join(data_path, 'subjects')
 
 
 def read_forward_solution_meg(*args, **kwargs):
@@ -46,6 +47,7 @@ def test_simulate_stc():
 
     stc_data = np.ones((len(labels), n_times))
     stc = simulate_stc(fwd['src'], mylabels, stc_data, tmin, tstep)
+    assert_equal(stc.subject, 'sample')
 
     for label in labels:
         if label.hemi == 'lh':
@@ -84,6 +86,15 @@ def test_simulate_stc():
         res = ((2. * i) ** 2.) * np.ones((len(idx), n_times))
         assert_array_almost_equal(stc.data[idx], res)
 
+    # degenerate conditions
+    label_subset = mylabels[:2]
+    data_subset = stc_data[:2]
+    stc = simulate_stc(fwd['src'], label_subset, data_subset, tmin, tstep, fun)
+    assert_raises(ValueError, simulate_stc, fwd['src'],
+                  label_subset, data_subset[:-1], tmin, tstep, fun)
+    assert_raises(RuntimeError, simulate_stc, fwd['src'], label_subset * 2,
+                  np.concatenate([data_subset] * 2, axis=0), tmin, tstep, fun)
+
 
 @testing.requires_testing_data
 def test_simulate_sparse_stc():
@@ -97,18 +108,40 @@ def test_simulate_sparse_stc():
     tstep = 1e-3
     times = np.arange(n_times, dtype=np.float) * tstep + tmin
 
-    stc_1 = simulate_sparse_stc(fwd['src'], len(labels), times,
-                                labels=labels, random_state=0)
+    assert_raises(ValueError, simulate_sparse_stc, fwd['src'], len(labels),
+                  times, labels=labels, location='center', subject='sample',
+                  subjects_dir=subjects_dir)  # no non-zero values
+    for label in labels:
+        label.values.fill(1.)
+    for location in ('random', 'center'):
+        random_state = 0 if location == 'random' else None
+        stc_1 = simulate_sparse_stc(fwd['src'], len(labels), times,
+                                    labels=labels, random_state=random_state,
+                                    location=location,
+                                    subjects_dir=subjects_dir)
+        assert_equal(stc_1.subject, 'sample')
 
-    assert_true(stc_1.data.shape[0] == len(labels))
-    assert_true(stc_1.data.shape[1] == n_times)
+        assert_true(stc_1.data.shape[0] == len(labels))
+        assert_true(stc_1.data.shape[1] == n_times)
 
-    # make sure we get the same result when using the same seed
-    stc_2 = simulate_sparse_stc(fwd['src'], len(labels), times,
-                                labels=labels, random_state=0)
+        # make sure we get the same result when using the same seed
+        stc_2 = simulate_sparse_stc(fwd['src'], len(labels), times,
+                                    labels=labels, random_state=random_state,
+                                    location=location,
+                                    subjects_dir=subjects_dir)
 
-    assert_array_equal(stc_1.lh_vertno, stc_2.lh_vertno)
-    assert_array_equal(stc_1.rh_vertno, stc_2.rh_vertno)
+        assert_array_equal(stc_1.lh_vertno, stc_2.lh_vertno)
+        assert_array_equal(stc_1.rh_vertno, stc_2.rh_vertno)
+    # Degenerate cases
+    assert_raises(ValueError, simulate_sparse_stc, fwd['src'], len(labels),
+                  times, labels=labels, location='center', subject='foo',
+                  subjects_dir=subjects_dir)  # wrong subject
+    del fwd['src'][0]['subject_his_id']
+    assert_raises(ValueError, simulate_sparse_stc, fwd['src'], len(labels),
+                  times, labels=labels, location='center',
+                  subjects_dir=subjects_dir)  # no subject
+    assert_raises(ValueError, simulate_sparse_stc, fwd['src'], len(labels),
+                  times, labels=labels, location='foo')  # bad location
 
 
 @testing.requires_testing_data
