@@ -4,14 +4,17 @@ import os
 from nose.tools import assert_true, assert_raises
 import numpy as np
 from numpy.testing import (assert_array_almost_equal, assert_array_equal,
-                           assert_equal)
+                           assert_equal, assert_allclose)
 import warnings
 
 from mne import (read_events, write_events, make_fixed_length_events,
-                 find_events, pick_events, find_stim_steps, io, pick_channels)
+                 find_events, pick_events, find_stim_steps, pick_channels,
+                 read_evokeds, Epochs)
+from mne.io import read_raw_fif
 from mne.tests.common import assert_naming
 from mne.utils import _TempDir, run_tests_if_main
-from mne.event import define_target_events, merge_events
+from mne.event import define_target_events, merge_events, AcqParserFIF
+from mne.datasets import testing
 
 warnings.simplefilter('always')
 
@@ -22,6 +25,11 @@ fname_1 = op.join(base_dir, 'test-1-eve.fif')
 fname_txt = op.join(base_dir, 'test-eve.eve')
 fname_txt_1 = op.join(base_dir, 'test-eve-1.eve')
 
+# for testing Elekta averager
+elekta_base_dir = op.join(testing.data_path(download=False), 'misc')
+fname_raw_elekta = op.join(elekta_base_dir, 'test_elekta_3ch_raw.fif')
+fname_ave_elekta = op.join(elekta_base_dir, 'test_elekta-ave.fif')
+
 # using mne_process_raw --raw test_raw.fif --eventsout test-mpr-eve.eve:
 fname_txt_mpr = op.join(base_dir, 'test-mpr-eve.eve')
 fname_old_txt = op.join(base_dir, 'test-eve-old-style.eve')
@@ -29,8 +37,8 @@ raw_fname = op.join(base_dir, 'test_raw.fif')
 
 
 def test_fix_stim():
-    """Test fixing stim STI016 for Neuromag"""
-    raw = io.read_raw_fif(raw_fname, preload=True)
+    """Test fixing stim STI016 for Neuromag."""
+    raw = read_raw_fif(raw_fname, preload=True, add_eeg_ref=False)
     # 32768 (016) + 3 (002+001) bits gets incorrectly coded during acquisition
     raw._data[raw.ch_names.index('STI 014'), :3] = [0, -32765, 0]
     with warnings.catch_warnings(record=True) as w:
@@ -43,12 +51,12 @@ def test_fix_stim():
 
 
 def test_add_events():
-    """Test adding events to a Raw file"""
+    """Test adding events to a Raw file."""
     # need preload
-    raw = io.read_raw_fif(raw_fname, preload=False)
+    raw = read_raw_fif(raw_fname, preload=False, add_eeg_ref=False)
     events = np.array([[raw.first_samp, 0, 1]])
     assert_raises(RuntimeError, raw.add_events, events, 'STI 014')
-    raw = io.read_raw_fif(raw_fname, preload=True)
+    raw = read_raw_fif(raw_fname, preload=True, add_eeg_ref=False)
     orig_events = find_events(raw, 'STI 014')
     # add some events
     events = np.array([raw.first_samp, 0, 1])
@@ -66,7 +74,7 @@ def test_add_events():
 
 
 def test_merge_events():
-    """Test event merging"""
+    """Test event merging."""
     events_orig = [[1, 0, 1], [3, 0, 2], [10, 0, 3], [20, 0, 4]]
 
     events_replacement = \
@@ -98,7 +106,7 @@ def test_merge_events():
 
 
 def test_io_events():
-    """Test IO for events"""
+    """Test IO for events."""
     tempdir = _TempDir()
     # Test binary fif IO
     events = read_events(fname)  # Use as the gold standard
@@ -119,7 +127,7 @@ def test_io_events():
     assert_array_almost_equal(events, events2)
     with warnings.catch_warnings(record=True) as w:
         warnings.simplefilter('always')
-        events2 = read_events(fname_txt_mpr)
+        events2 = read_events(fname_txt_mpr, mask=0, mask_type='not_and')
         assert_true(sum('first row of' in str(ww.message) for ww in w) == 1)
     assert_array_almost_equal(events, events2)
 
@@ -169,9 +177,9 @@ def test_io_events():
 
 
 def test_find_events():
-    """Test find events in raw file"""
+    """Test find events in raw file."""
     events = read_events(fname)
-    raw = io.read_raw_fif(raw_fname, preload=True)
+    raw = read_raw_fif(raw_fname, preload=True, add_eeg_ref=False)
     # let's test the defaulting behavior while we're at it
     extra_ends = ['', '_1']
     orig_envs = [os.getenv('MNE_STIM_CHANNEL%s' % s) for s in extra_ends]
@@ -181,7 +189,7 @@ def test_find_events():
     events2 = find_events(raw)
     assert_array_almost_equal(events, events2)
     # now test with mask
-    events11 = find_events(raw, mask=3)
+    events11 = find_events(raw, mask=3, mask_type='not_and')
     with warnings.catch_warnings(record=True) as w:
         warnings.simplefilter('always')
         events22 = read_events(fname, mask=3)
@@ -203,14 +211,33 @@ def test_find_events():
     # 1 == '0b1', 2 == '0b10', 3 == '0b11', 4 == '0b100'
 
     assert_raises(TypeError, find_events, raw, mask="0")
-    assert_array_equal(find_events(raw, shortest_event=1, mask=1),
+    assert_raises(ValueError, find_events, raw, mask=0, mask_type='blah')
+    # testing mask_type. default = 'not_and'
+    assert_array_equal(find_events(raw, shortest_event=1, mask=1,
+                                   mask_type='not_and'),
                        [[2, 0, 2], [4, 2, 4]])
-    assert_array_equal(find_events(raw, shortest_event=1, mask=2),
+    assert_array_equal(find_events(raw, shortest_event=1, mask=2,
+                                   mask_type='not_and'),
                        [[1, 0, 1], [3, 0, 1], [4, 1, 4]])
-    assert_array_equal(find_events(raw, shortest_event=1, mask=3),
+    assert_array_equal(find_events(raw, shortest_event=1, mask=3,
+                                   mask_type='not_and'),
                        [[4, 0, 4]])
-    assert_array_equal(find_events(raw, shortest_event=1, mask=4),
+    assert_array_equal(find_events(raw, shortest_event=1, mask=4,
+                                   mask_type='not_and'),
                        [[1, 0, 1], [2, 1, 2], [3, 2, 3]])
+    # testing with mask_type = 'and'
+    assert_array_equal(find_events(raw, shortest_event=1, mask=1,
+                       mask_type='and'),
+                       [[1, 0, 1], [3, 0, 1]])
+    assert_array_equal(find_events(raw, shortest_event=1, mask=2,
+                       mask_type='and'),
+                       [[2, 0, 2]])
+    assert_array_equal(find_events(raw, shortest_event=1, mask=3,
+                       mask_type='and'),
+                       [[1, 0, 1], [2, 1, 2], [3, 2, 3]])
+    assert_array_equal(find_events(raw, shortest_event=1, mask=4,
+                       mask_type='and'),
+                       [[4, 0, 4]])
 
     # test empty events channel
     raw._data[stim_channel_idx, :] = 0
@@ -318,7 +345,7 @@ def test_find_events():
 
 
 def test_pick_events():
-    """Test pick events in a events ndarray"""
+    """Test pick events in a events ndarray."""
     events = np.array([[1, 0, 1],
                        [2, 1, 0],
                        [3, 0, 4],
@@ -338,8 +365,8 @@ def test_pick_events():
 
 
 def test_make_fixed_length_events():
-    """Test making events of a fixed length"""
-    raw = io.read_raw_fif(raw_fname)
+    """Test making events of a fixed length."""
+    raw = read_raw_fif(raw_fname, add_eeg_ref=False)
     events = make_fixed_length_events(raw, id=1)
     assert_true(events.shape[1], 3)
     events_zero = make_fixed_length_events(raw, 1, first_samp=False)
@@ -353,12 +380,17 @@ def test_make_fixed_length_events():
     # With bad limits (no resulting events)
     assert_raises(ValueError, make_fixed_length_events, raw, 1,
                   tmin, tmax - 1e-3, duration)
+    # not raw, bad id or duration
+    assert_raises(ValueError, make_fixed_length_events, raw, 2.3)
+    assert_raises(ValueError, make_fixed_length_events, 'not raw', 2)
+    assert_raises(ValueError, make_fixed_length_events, raw, 23, tmin, tmax,
+                  'abc')
 
 
 def test_define_events():
-    """Test defining response events"""
+    """Test defining response events."""
     events = read_events(fname)
-    raw = io.read_raw_fif(raw_fname)
+    raw = read_raw_fif(raw_fname, add_eeg_ref=False)
     events_, _ = define_target_events(events, 5, 32, raw.info['sfreq'],
                                       .2, 0.7, 42, 99)
     n_target = events[events[:, 2] == 5].shape[0]
@@ -385,4 +417,75 @@ def test_define_events():
     assert_array_equal(true_lag_fill, lag_fill)
     assert_array_equal(true_lag_nofill, lag_nofill)
 
+
+@testing.requires_testing_data
+def test_acqparser():
+    """ Test AcqParserFIF """
+    # no acquisition parameters
+    assert_raises(ValueError, AcqParserFIF, {'acq_pars': ''})
+    # invalid acquisition parameters
+    assert_raises(ValueError, AcqParserFIF, {'acq_pars': 'baaa'})
+    assert_raises(ValueError, AcqParserFIF, {'acq_pars': 'ERFVersion\n1'})
+    # test oldish file
+    raw = read_raw_fif(raw_fname, preload=False)
+    acqp = AcqParserFIF(raw.info)
+    # test __repr__()
+    assert_true(repr(acqp))
+    # old file should trigger compat mode
+    assert_true(acqp.compat)
+    # count events and categories
+    assert_equal(len(acqp.categories), 6)
+    assert_equal(len(acqp._categories), 17)
+    assert_equal(len(acqp.events), 6)
+    assert_equal(len(acqp._events), 17)
+    # get category
+    assert_true(acqp['Surprise visual'])
+    # test TRIUX file
+    raw = read_raw_fif(fname_raw_elekta, preload=False)
+    acqp = AcqParserFIF(raw.info)
+    # test __repr__()
+    assert_true(repr(acqp))
+    # this file should not be in compatibility mode
+    assert_true(not acqp.compat)
+    # nonexisting category
+    assert_raises(KeyError, acqp.__getitem__, 'does not exist')
+    assert_raises(KeyError, acqp.get_condition, raw, 'foo')
+    # category not a string
+    assert_raises(ValueError, acqp.__getitem__, 0)
+    # number of events / categories
+    assert_equal(len(acqp), 7)
+    assert_equal(len(acqp.categories), 7)
+    assert_equal(len(acqp._categories), 32)
+    assert_equal(len(acqp.events), 6)
+    assert_equal(len(acqp._events), 32)
+    # get category
+    assert_true(acqp['Test event 5'])
+
+
+@testing.requires_testing_data
+def test_acqparser_averaging():
+    """ Test averaging with AcqParserFIF vs. Elekta software """
+    raw = read_raw_fif(fname_raw_elekta, preload=True)
+    acqp = AcqParserFIF(raw.info)
+    for cat in acqp.categories:
+        # XXX datasets match only when baseline is applied to both,
+        # not sure where relative dc shift comes from
+        cond = acqp.get_condition(raw, cat)
+        eps = Epochs(raw, baseline=(-.05, 0), **cond)
+        ev = eps.average()
+        ev_ref = read_evokeds(fname_ave_elekta, cat['comment'],
+                              baseline=(-.05, 0), proj=False)
+        ev_mag = ev.copy()
+        ev_mag.pick_channels(['MEG0111'])
+        ev_grad = ev.copy()
+        ev_grad.pick_channels(['MEG2643', 'MEG1622'])
+        ev_ref_mag = ev_ref.copy()
+        ev_ref_mag.pick_channels(['MEG0111'])
+        ev_ref_grad = ev_ref.copy()
+        ev_ref_grad.pick_channels(['MEG2643', 'MEG1622'])
+        assert_allclose(ev_mag.data, ev_ref_mag.data,
+                        rtol=0, atol=1e-15)  # tol = 1 fT
+        assert_allclose(ev_grad.data, ev_ref_grad.data,
+                        rtol=0, atol=1e-13)  # tol = 1 fT/cm
+
 run_tests_if_main()
