@@ -16,9 +16,10 @@ from numpy.testing import (assert_array_almost_equal, assert_equal,
 from nose.tools import assert_true, assert_raises, assert_not_equal
 
 from mne import (equalize_channels, pick_types, read_evokeds, write_evokeds,
-                 grand_average, combine_evoked, create_info)
+                 grand_average, combine_evoked, create_info, read_events,
+                 Epochs, EpochsArray)
 from mne.evoked import _get_peak, Evoked, EvokedArray
-from mne.epochs import EpochsArray
+from mne.io import read_raw_fif
 from mne.tests.common import assert_naming
 from mne.utils import (_TempDir, requires_pandas, slow_test, requires_version,
                        run_tests_if_main)
@@ -26,16 +27,57 @@ from mne.externals.six.moves import cPickle as pickle
 
 warnings.simplefilter('always')
 
-fname = op.join(op.dirname(__file__), '..', 'io', 'tests', 'data',
-                'test-ave.fif')
-fname_gz = op.join(op.dirname(__file__), '..', 'io', 'tests', 'data',
-                   'test-ave.fif.gz')
+base_dir = op.join(op.dirname(__file__), '..', 'io', 'tests', 'data')
+fname = op.join(base_dir, 'test-ave.fif')
+fname_gz = op.join(base_dir, 'test-ave.fif.gz')
+raw_fname = op.join(base_dir, 'test_raw.fif')
+event_name = op.join(base_dir, 'test-eve.fif')
+
+
+def test_decim():
+    """Test evoked decimation."""
+    rng = np.random.RandomState(0)
+    n_epochs, n_channels, n_times = 5, 10, 20
+    dec_1, dec_2 = 2, 3
+    decim = dec_1 * dec_2
+    sfreq = 1000.
+    sfreq_new = sfreq / decim
+    data = rng.randn(n_epochs, n_channels, n_times)
+    events = np.array([np.arange(n_epochs), [0] * n_epochs, [1] * n_epochs]).T
+    info = create_info(n_channels, sfreq, 'eeg')
+    info['lowpass'] = sfreq_new / float(decim)
+    epochs = EpochsArray(data, info, events)
+    data_epochs = epochs.copy().decimate(decim).get_data()
+    data_epochs_2 = epochs.copy().decimate(decim, offset=1).get_data()
+    data_epochs_3 = epochs.decimate(dec_1).decimate(dec_2).get_data()
+    assert_array_equal(data_epochs, data[:, :, ::decim])
+    assert_array_equal(data_epochs_2, data[:, :, 1::decim])
+    assert_array_equal(data_epochs, data_epochs_3)
+
+    # Now let's do it with some real data
+    raw = read_raw_fif(raw_fname, add_eeg_ref=False)
+    events = read_events(event_name)
+    sfreq_new = raw.info['sfreq'] / decim
+    raw.info['lowpass'] = sfreq_new / 4.  # suppress aliasing warnings
+    picks = pick_types(raw.info, meg=True, eeg=True, exclude=())
+    epochs = Epochs(raw, events, 1, -0.2, 0.5, picks=picks, preload=True,
+                    add_eeg_ref=False)
+    for offset in (0, 1):
+        ev_ep_decim = epochs.copy().decimate(decim, offset).average()
+        ev_decim = epochs.average().decimate(decim, offset)
+        expected_times = epochs.times[offset::decim]
+        assert_allclose(ev_decim.times, expected_times)
+        assert_allclose(ev_ep_decim.times, expected_times)
+        expected_data = epochs.get_data()[:, :, offset::decim].mean(axis=0)
+        assert_allclose(ev_decim.data, expected_data)
+        assert_allclose(ev_ep_decim.data, expected_data)
+        assert_equal(ev_decim.info['sfreq'], sfreq_new)
+        assert_array_equal(ev_decim.times, expected_times)
 
 
 @requires_version('scipy', '0.14')
 def test_savgol_filter():
-    """Test savgol filtering
-    """
+    """Test savgol filtering."""
     h_freq = 10.
     evoked = read_evokeds(fname, 0)
     freqs = fftpack.fftfreq(len(evoked.times), 1. / evoked.info['sfreq'])
@@ -57,8 +99,7 @@ def test_savgol_filter():
 
 
 def test_hash_evoked():
-    """Test evoked hashing
-    """
+    """Test evoked hashing."""
     ave = read_evokeds(fname, 0)
     ave_2 = read_evokeds(fname, 0)
     assert_equal(hash(ave), hash(ave_2))
@@ -71,8 +112,7 @@ def test_hash_evoked():
 
 @slow_test
 def test_io_evoked():
-    """Test IO for evoked data (fif + gz) with integer and str args
-    """
+    """Test IO for evoked data (fif + gz) with integer and str args."""
     tempdir = _TempDir()
     ave = read_evokeds(fname, 0)
 
@@ -119,9 +159,9 @@ def test_io_evoked():
             assert_equal(av1.comment, av2.comment)
 
     # test warnings on bad filenames
+    fname2 = op.join(tempdir, 'test-bad-name.fif')
     with warnings.catch_warnings(record=True) as w:
         warnings.simplefilter('always')
-        fname2 = op.join(tempdir, 'test-bad-name.fif')
         write_evokeds(fname2, ave)
         read_evokeds(fname2)
     assert_naming(w, 'test_evoked.py', 2)
@@ -129,10 +169,24 @@ def test_io_evoked():
     # constructor
     assert_raises(TypeError, Evoked, fname)
 
+    # MaxShield
+    fname_ms = op.join(tempdir, 'test-ave.fif')
+    assert_true(ave.info['maxshield'] is False)
+    ave.info['maxshield'] = True
+    ave.save(fname_ms)
+    assert_raises(ValueError, read_evokeds, fname_ms)
+    with warnings.catch_warnings(record=True) as w:
+        aves = read_evokeds(fname_ms, allow_maxshield=True)
+    assert_true(all('Elekta' in str(ww.message) for ww in w))
+    assert_true(all(ave.info['maxshield'] is True for ave in aves))
+    with warnings.catch_warnings(record=True) as w:
+        aves = read_evokeds(fname_ms, allow_maxshield='yes')
+    assert_equal(len(w), 0)
+    assert_true(all(ave.info['maxshield'] is True for ave in aves))
+
 
 def test_shift_time_evoked():
-    """ Test for shifting of time scale
-    """
+    """ Test for shifting of time scale."""
     tempdir = _TempDir()
     # Shift backward
     ave = read_evokeds(fname, 0)
@@ -172,8 +226,7 @@ def test_shift_time_evoked():
 
 
 def test_evoked_resample():
-    """Test for resampling of evoked data
-    """
+    """Test for resampling of evoked data."""
     tempdir = _TempDir()
     # upsample, write it out, read it in
     ave = read_evokeds(fname, 0)
@@ -204,8 +257,7 @@ def test_evoked_resample():
 
 
 def test_evoked_detrend():
-    """Test for detrending evoked data
-    """
+    """Test for detrending evoked data."""
     ave = read_evokeds(fname, 0)
     ave_normal = read_evokeds(fname, 0)
     ave.detrend(0)
@@ -217,7 +269,7 @@ def test_evoked_detrend():
 
 @requires_pandas
 def test_to_data_frame():
-    """Test evoked Pandas exporter"""
+    """Test evoked Pandas exporter."""
     ave = read_evokeds(fname, 0)
     assert_raises(ValueError, ave.to_data_frame, picks=np.arange(400))
     df = ave.to_data_frame()
@@ -229,8 +281,7 @@ def test_to_data_frame():
 
 
 def test_evoked_proj():
-    """Test SSP proj operations
-    """
+    """Test SSP proj operations."""
     for proj in [True, False]:
         ave = read_evokeds(fname, condition=0, proj=proj)
         assert_true(all(p['active'] == proj for p in ave.info['projs']))
@@ -258,9 +309,7 @@ def test_evoked_proj():
 
 
 def test_get_peak():
-    """Test peak getter
-    """
-
+    """Test peak getter."""
     evoked = read_evokeds(fname, condition=0, proj=True)
     assert_raises(ValueError, evoked.get_peak, ch_type='mag', tmin=1)
     assert_raises(ValueError, evoked.get_peak, ch_type='mag', tmax=0.9)
@@ -301,8 +350,7 @@ def test_get_peak():
 
 
 def test_drop_channels_mixin():
-    """Test channels-dropping functionality
-    """
+    """Test channels-dropping functionality."""
     evoked = read_evokeds(fname, condition=0, proj=True)
     drop_ch = evoked.ch_names[:3]
     ch_names = evoked.ch_names[3:]
@@ -312,15 +360,19 @@ def test_drop_channels_mixin():
     assert_equal(ch_names, dummy.ch_names)
     assert_equal(ch_names_orig, evoked.ch_names)
     assert_equal(len(ch_names_orig), len(evoked.data))
+    dummy2 = evoked.copy().drop_channels([drop_ch[0]])
+    assert_equal(dummy2.ch_names, ch_names_orig[1:])
 
     evoked.drop_channels(drop_ch)
     assert_equal(ch_names, evoked.ch_names)
     assert_equal(len(ch_names), len(evoked.data))
 
+    for ch_names in ([1, 2], "fake", ["fake"]):
+        assert_raises(ValueError, evoked.drop_channels, ch_names)
+
 
 def test_pick_channels_mixin():
-    """Test channel-picking functionality
-    """
+    """Test channel-picking functionality."""
     evoked = read_evokeds(fname, condition=0, proj=True)
     ch_names = evoked.ch_names[:3]
 
@@ -344,8 +396,7 @@ def test_pick_channels_mixin():
 
 
 def test_equalize_channels():
-    """Test equalization of channels
-    """
+    """Test equalization of channels."""
     evoked1 = read_evokeds(fname, condition=0, proj=True)
     evoked2 = evoked1.copy()
     ch_names = evoked1.ch_names[2:]
@@ -357,9 +408,8 @@ def test_equalize_channels():
         assert_equal(ch_names, e.ch_names)
 
 
-def test_evoked_arithmetic():
-    """Test evoked arithmetic
-    """
+def test_arithmetic():
+    """Test evoked arithmetic."""
     ev = read_evokeds(fname, condition=0)
     ev1 = EvokedArray(np.ones_like(ev.data), ev.info, ev.times[0], nave=20)
     ev2 = EvokedArray(-np.ones_like(ev.data), ev.info, ev.times[0], nave=10)
@@ -367,22 +417,35 @@ def test_evoked_arithmetic():
     # combine_evoked([ev1, ev2]) should be the same as ev1 + ev2:
     # data should be added according to their `nave` weights
     # nave = ev1.nave + ev2.nave
-    ev = ev1 + ev2
+    with warnings.catch_warnings(record=True):  # deprecation no weights
+        ev = combine_evoked([ev1, ev2])
     assert_equal(ev.nave, ev1.nave + ev2.nave)
     assert_allclose(ev.data, 1. / 3. * np.ones_like(ev.data))
-    ev = ev1 - ev2
-    assert_equal(ev.nave, ev1.nave + ev2.nave)
-    assert_equal(ev.comment, ev1.comment + ' - ' + ev2.comment)
-    assert_allclose(ev.data, np.ones_like(ev1.data))
+
+    # with same trial counts, a bunch of things should be equivalent
+    for weights in ('nave', 'equal', [0.5, 0.5]):
+        ev = combine_evoked([ev1, ev1], weights=weights)
+        assert_allclose(ev.data, ev1.data)
+        assert_equal(ev.nave, 2 * ev1.nave)
+        ev = combine_evoked([ev1, -ev1], weights=weights)
+        assert_allclose(ev.data, 0., atol=1e-20)
+        assert_equal(ev.nave, 2 * ev1.nave)
+    ev = combine_evoked([ev1, -ev1], weights='equal')
+    assert_allclose(ev.data, 0., atol=1e-20)
+    assert_equal(ev.nave, 2 * ev1.nave)
+    ev = combine_evoked([ev1, -ev2], weights='equal')
+    expected = int(round(1. / (0.25 / ev1.nave + 0.25 / ev2.nave)))
+    assert_equal(expected, 27)  # this is reasonable
+    assert_equal(ev.nave, expected)
 
     # default comment behavior if evoked.comment is None
     old_comment1 = ev1.comment
     old_comment2 = ev2.comment
     ev1.comment = None
-    with warnings.catch_warnings(record=True):
-        warnings.simplefilter('always')
-        ev = ev1 - ev2
-        assert_equal(ev.comment, 'unknown')
+    ev = combine_evoked([ev1, -ev2], weights=[1, -1])
+    assert_equal(ev.comment.count('unknown'), 2)
+    assert_true('-unknown' in ev.comment)
+    assert_true(' + ' in ev.comment)
     ev1.comment = old_comment1
     ev2.comment = old_comment2
 
@@ -412,11 +475,11 @@ def test_evoked_arithmetic():
     assert_equal(gave.data.shape, [len(ch_names), evoked1.data.shape[1]])
     assert_equal(ch_names, gave.ch_names)
     assert_equal(gave.nave, 2)
+    assert_raises(ValueError, grand_average, [1, evoked1])
 
 
 def test_array_epochs():
-    """Test creating evoked from array
-    """
+    """Test creating evoked from array."""
     tempdir = _TempDir()
 
     # creating
@@ -463,14 +526,14 @@ def test_array_epochs():
 
 
 def test_time_as_index():
-    """Test time as index"""
+    """Test time as index."""
     evoked = read_evokeds(fname, condition=0).crop(-.1, .1)
     assert_array_equal(evoked.time_as_index([-.1, .1], use_rounding=True),
                        [0, len(evoked.times) - 1])
 
 
 def test_add_channels():
-    """Test evoked splitting / re-appending channel types"""
+    """Test evoked splitting / re-appending channel types."""
     evoked = read_evokeds(fname, condition=0)
     evoked.info['buffer_size_sec'] = None
     hpi_coils = [{'event_bits': []},
@@ -502,4 +565,18 @@ def test_add_channels():
     assert_raises(AssertionError, evoked_meg.add_channels, evoked_badsf)
 
 
+def test_evoked_baseline():
+    """Test evoked baseline."""
+    evoked = read_evokeds(fname, condition=0, baseline=None)
+
+    # Here we create a data_set with constant data.
+    evoked = EvokedArray(np.ones_like(evoked.data), evoked.info,
+                         evoked.times[0])
+
+    # Mean baseline correction is applied, since the data is equal to its mean
+    # the resulting data should be a matrix of zeroes.
+    evoked.apply_baseline((None, None))
+
+    assert_allclose(evoked.data, np.zeros_like(evoked.data))
+
 run_tests_if_main()
