@@ -13,9 +13,11 @@ from mne import read_surface, write_surface, decimate_surface
 from mne.surface import (read_morph_map, _compute_nearest,
                          fast_cross_3d, get_head_surf, read_curvature,
                          get_meg_helmet_surf)
-from mne.utils import _TempDir, requires_mayavi, run_tests_if_main, slow_test
+from mne.utils import (_TempDir, requires_mayavi, requires_tvtk,
+                       run_tests_if_main, slow_test)
 from mne.io import read_info
 from mne.transforms import _get_trans
+from mne.io.meas_info import _is_equal_dict
 
 data_path = testing.data_path(download=False)
 subjects_dir = op.join(data_path, 'subjects')
@@ -27,8 +29,7 @@ rng = np.random.RandomState(0)
 
 
 def test_helmet():
-    """Test loading helmet surfaces
-    """
+    """Test loading helmet surfaces."""
     base_dir = op.join(op.dirname(__file__), '..', 'io')
     fname_raw = op.join(base_dir, 'tests', 'data', 'test_raw.fif')
     fname_kit_raw = op.join(base_dir, 'kit', 'tests', 'data',
@@ -47,8 +48,7 @@ def test_helmet():
 
 @testing.requires_testing_data
 def test_head():
-    """Test loading the head surface
-    """
+    """Test loading the head surface."""
     surf_1 = get_head_surf('sample', subjects_dir=subjects_dir)
     surf_2 = get_head_surf('sample', 'head', subjects_dir=subjects_dir)
     assert_true(len(surf_1['rr']) < len(surf_2['rr']))  # BEM vs dense head
@@ -57,8 +57,7 @@ def test_head():
 
 
 def test_huge_cross():
-    """Test cross product with lots of elements
-    """
+    """Test cross product with lots of elements."""
     x = rng.rand(100000, 3)
     y = rng.rand(1, 3)
     z = np.cross(x, y)
@@ -67,7 +66,7 @@ def test_huge_cross():
 
 
 def test_compute_nearest():
-    """Test nearest neighbor searches"""
+    """Test nearest neighbor searches."""
     x = rng.randn(500, 3)
     x /= np.sqrt(np.sum(x ** 2, axis=1))[:, None]
     nn_true = rng.permutation(np.arange(500, dtype=np.int))[:20]
@@ -91,8 +90,7 @@ def test_compute_nearest():
 @slow_test
 @testing.requires_testing_data
 def test_make_morph_maps():
-    """Test reading and creating morph maps
-    """
+    """Test reading and creating morph maps."""
     # make a new fake subjects_dir
     tempdir = _TempDir()
     for subject in ('sample', 'sample_ds', 'fsaverage_ds'):
@@ -122,25 +120,28 @@ def test_make_morph_maps():
 
 @testing.requires_testing_data
 def test_io_surface():
-    """Test reading and writing of Freesurfer surface mesh files
-    """
+    """Test reading and writing of Freesurfer surface mesh files."""
     tempdir = _TempDir()
     fname_quad = op.join(data_path, 'subjects', 'bert', 'surf',
                          'lh.inflated.nofix')
     fname_tri = op.join(data_path, 'subjects', 'fsaverage', 'surf',
                         'lh.inflated')
     for fname in (fname_quad, fname_tri):
-        pts, tri = read_surface(fname)
-        write_surface(op.join(tempdir, 'tmp'), pts, tri)
-        c_pts, c_tri = read_surface(op.join(tempdir, 'tmp'))
+        with warnings.catch_warnings(record=True) as w:
+            pts, tri, vol_info = read_surface(fname, read_metadata=True)
+        assert_true(all('No volume info' in str(ww.message) for ww in w))
+        write_surface(op.join(tempdir, 'tmp'), pts, tri, volume_info=vol_info)
+        with warnings.catch_warnings(record=True) as w:  # No vol info
+            c_pts, c_tri, c_vol_info = read_surface(op.join(tempdir, 'tmp'),
+                                                    read_metadata=True)
         assert_array_equal(pts, c_pts)
         assert_array_equal(tri, c_tri)
+        assert_true(_is_equal_dict([vol_info, c_vol_info]))
 
 
 @testing.requires_testing_data
 def test_read_curv():
-    """Test reading curvature data
-    """
+    """Test reading curvature data."""
     fname_curv = op.join(data_path, 'subjects', 'fsaverage', 'surf', 'lh.curv')
     fname_surf = op.join(data_path, 'subjects', 'fsaverage', 'surf',
                          'lh.inflated')
@@ -150,10 +151,10 @@ def test_read_curv():
     assert_true(np.logical_or(bin_curv == 0, bin_curv == 1).all())
 
 
+@requires_tvtk
 @requires_mayavi
 def test_decimate_surface():
-    """Test triangular surface decimation
-    """
+    """Test triangular surface decimation."""
     points = np.array([[-0.00686118, -0.10369860, 0.02615170],
                        [-0.00713948, -0.10370162, 0.02614874],
                        [-0.00686208, -0.10368247, 0.02588313],
