@@ -4,15 +4,17 @@ from numpy.testing import assert_array_almost_equal, assert_array_equal
 from nose.tools import assert_true, assert_false, assert_equal, assert_raises
 
 import mne
-from mne import io, Epochs, read_events, pick_types, create_info, EpochsArray
+from mne import Epochs, read_events, pick_types, create_info, EpochsArray
+from mne.io import read_raw_fif
 from mne.utils import (_TempDir, run_tests_if_main, slow_test, requires_h5py,
                        grand_average)
 from mne.time_frequency import single_trial_power
 from mne.time_frequency.tfr import (cwt_morlet, morlet, tfr_morlet,
-                                    _dpss_wavelet, tfr_multitaper,
+                                    _make_dpss, tfr_multitaper, rescale,
                                     AverageTFR, read_tfrs, write_tfrs,
-                                    combine_tfr, cwt)
-
+                                    combine_tfr, cwt, _compute_tfr)
+from mne.viz.utils import _fake_click
+from itertools import product
 import matplotlib
 matplotlib.use('Agg')  # for testing don't use X server
 
@@ -23,7 +25,7 @@ event_fname = op.join(op.dirname(__file__), '..', '..', 'io', 'tests',
 
 
 def test_morlet():
-    """Test morlet with and without zero mean"""
+    """Test morlet with and without zero mean."""
     Wz = morlet(1000, [10], 2., zero_mean=True)
     W = morlet(1000, [10], 2., zero_mean=False)
 
@@ -32,15 +34,14 @@ def test_morlet():
 
 
 def test_time_frequency():
-    """Test time frequency transform (PSD and phase lock)
-    """
+    """Test the to-be-deprecated time-frequency transform (PSD and ITC)."""
     # Set parameters
     event_id = 1
     tmin = -0.2
     tmax = 0.498  # Allows exhaustive decimation testing
 
     # Setup for reading the raw data
-    raw = io.read_raw_fif(raw_fname)
+    raw = read_raw_fif(raw_fname, add_eeg_ref=False)
     events = read_events(event_fname)
 
     include = []
@@ -52,13 +53,13 @@ def test_time_frequency():
 
     picks = picks[:2]
     epochs = Epochs(raw, events, event_id, tmin, tmax, picks=picks,
-                    baseline=(None, 0))
+                    baseline=(None, 0), add_eeg_ref=False)
     data = epochs.get_data()
     times = epochs.times
     nave = len(data)
 
     epochs_nopicks = Epochs(raw, events, event_id, tmin, tmax,
-                            baseline=(None, 0))
+                            baseline=(None, 0), add_eeg_ref=False)
 
     freqs = np.arange(6, 20, 5)  # define frequencies of interest
     n_cycles = freqs / 4.
@@ -75,21 +76,32 @@ def test_time_frequency():
                             use_fft=True, return_itc=True)
     power_, itc_ = tfr_morlet(epochs, freqs=freqs, n_cycles=n_cycles,
                               use_fft=True, return_itc=True, decim=slice(0, 2))
-    # Test picks argument
-    power_picks, itc_picks = tfr_morlet(epochs_nopicks, freqs=freqs,
-                                        n_cycles=n_cycles, use_fft=True,
-                                        return_itc=True, picks=picks)
+    # Test picks argument and average parameter
+    assert_raises(ValueError, tfr_morlet, epochs, freqs=freqs,
+                  n_cycles=n_cycles, return_itc=True, average=False)
+
+    power_picks, itc_picks = \
+        tfr_morlet(epochs_nopicks,
+                   freqs=freqs, n_cycles=n_cycles, use_fft=True,
+                   return_itc=True, picks=picks, average=True)
+
+    epochs_power_picks = \
+        tfr_morlet(epochs_nopicks,
+                   freqs=freqs, n_cycles=n_cycles, use_fft=True,
+                   return_itc=False, picks=picks, average=False)
+    power_picks_avg = epochs_power_picks.average()
     # the actual data arrays here are equivalent, too...
     assert_array_almost_equal(power.data, power_picks.data)
+    assert_array_almost_equal(power.data, power_picks_avg.data)
     assert_array_almost_equal(itc.data, itc_picks.data)
     assert_array_almost_equal(power.data, power_evoked.data)
 
     print(itc)  # test repr
     print(itc.ch_names)  # test property
     itc += power  # test add
-    itc -= power  # test add
+    itc -= power  # test sub
 
-    power.apply_baseline(baseline=(-0.1, 0), mode='logratio')
+    power = power.apply_baseline(baseline=(-0.1, 0), mode='logratio')
 
     assert_true('meg' in power)
     assert_true('grad' in power)
@@ -209,10 +221,10 @@ def test_time_frequency():
 
 
 def test_dpsswavelet():
-    """Test DPSS wavelet"""
+    """Test DPSS tapers."""
     freqs = np.arange(5, 25, 3)
-    Ws = _dpss_wavelet(1000, freqs=freqs, n_cycles=freqs / 2.,
-                       time_bandwidth=4.0, zero_mean=True)
+    Ws = _make_dpss(1000, freqs=freqs, n_cycles=freqs / 2., time_bandwidth=4.0,
+                    zero_mean=True)
 
     assert_true(len(Ws) == 3)  # 3 tapers expected
 
@@ -224,10 +236,10 @@ def test_dpsswavelet():
 
 @slow_test
 def test_tfr_multitaper():
-    """Test tfr_multitaper"""
+    """Test tfr_multitaper."""
     sfreq = 200.0
-    ch_names = ['SIM0001', 'SIM0002', 'SIM0003']
-    ch_types = ['grad', 'grad', 'grad']
+    ch_names = ['SIM0001', 'SIM0002']
+    ch_types = ['grad', 'grad']
     info = create_info(ch_names=ch_names, sfreq=sfreq, ch_types=ch_types)
 
     n_times = int(sfreq)  # Second long epochs
@@ -252,7 +264,8 @@ def test_tfr_multitaper():
     epochs = EpochsArray(data=dat, info=info, events=events, event_id=event_id,
                          reject=reject)
 
-    freqs = np.arange(5, 100, 3, dtype=np.float)
+    freqs = np.arange(35, 70, 5, dtype=np.float)
+
     power, itc = tfr_multitaper(epochs, freqs=freqs, n_cycles=freqs / 2.,
                                 time_bandwidth=4.0)
     power2, itc2 = tfr_multitaper(epochs, freqs=freqs, n_cycles=freqs / 2.,
@@ -261,11 +274,27 @@ def test_tfr_multitaper():
     power_picks, itc_picks = tfr_multitaper(epochs, freqs=freqs,
                                             n_cycles=freqs / 2.,
                                             time_bandwidth=4.0, picks=picks)
+    power_epochs = tfr_multitaper(epochs, freqs=freqs,
+                                  n_cycles=freqs / 2., time_bandwidth=4.0,
+                                  return_itc=False, average=False)
+    power_averaged = power_epochs.average()
     power_evoked = tfr_multitaper(epochs.average(), freqs=freqs,
                                   n_cycles=freqs / 2., time_bandwidth=4.0,
-                                  return_itc=False)
+                                  return_itc=False, average=False).average()
+
+    print(power_evoked)  # test repr for EpochsTFR
+
+    assert_raises(ValueError, tfr_multitaper, epochs,
+                  freqs=freqs, n_cycles=freqs / 2.,
+                  return_itc=True, average=False)
+
     # test picks argument
     assert_array_almost_equal(power.data, power_picks.data)
+    assert_array_almost_equal(power.data, power_averaged.data)
+    assert_array_almost_equal(power.times, power_epochs.times)
+    assert_array_almost_equal(power.times, power_averaged.times)
+    assert_equal(power.nave, power_averaged.nave)
+    assert_equal(power_epochs.data.shape, (3, 2, 7, 200))
     assert_array_almost_equal(itc.data, itc_picks.data)
     # one is squared magnitude of the average (evoked) and
     # the other is average of the squared magnitudes (epochs PSD)
@@ -291,7 +320,7 @@ def test_tfr_multitaper():
 
 
 def test_crop():
-    """Test TFR cropping"""
+    """Test TFR cropping."""
     data = np.zeros((3, 2, 3))
     times = np.array([.1, .2, .3])
     freqs = np.array([.10, .20])
@@ -306,7 +335,7 @@ def test_crop():
 
 @requires_h5py
 def test_io():
-    """Test TFR IO capacities"""
+    """Test TFR IO capacities."""
 
     tempdir = _TempDir()
     fname = op.join(tempdir, 'test-tfr.h5')
@@ -375,10 +404,29 @@ def test_plot():
     tfr.plot_topo(picks=[1, 2])
     plt.close('all')
 
+    fig = tfr.plot(picks=[1], cmap='RdBu_r')  # interactive mode on by default
+    fig.canvas.key_press_event('up')
+    fig.canvas.key_press_event(' ')
+    fig.canvas.key_press_event('down')
+
+    cbar = fig.get_axes()[0].CB  # Fake dragging with mouse.
+    ax = cbar.cbar.ax
+    _fake_click(fig, ax, (0.1, 0.1))
+    _fake_click(fig, ax, (0.1, 0.2), kind='motion')
+    _fake_click(fig, ax, (0.1, 0.3), kind='release')
+
+    _fake_click(fig, ax, (0.1, 0.1), button=3)
+    _fake_click(fig, ax, (0.1, 0.2), button=3, kind='motion')
+    _fake_click(fig, ax, (0.1, 0.3), kind='release')
+
+    fig.canvas.scroll_event(0.5, 0.5, -0.5)  # scroll down
+    fig.canvas.scroll_event(0.5, 0.5, 0.5)  # scroll up
+
+    plt.close('all')
+
 
 def test_add_channels():
-    """Test tfr splitting / re-appending channel types
-    """
+    """Test tfr splitting / re-appending channel types."""
     data = np.zeros((6, 2, 3))
     times = np.array([.1, .2, .3])
     freqs = np.array([.10, .20])
@@ -412,4 +460,119 @@ def test_add_channels():
     assert_raises(AssertionError, tfr_meg.add_channels, tfr_badsf)
 
 
+def test_compute_tfr():
+    """Test _compute_tfr function."""
+    # Set parameters
+    event_id = 1
+    tmin = -0.2
+    tmax = 0.498  # Allows exhaustive decimation testing
+
+    # Setup for reading the raw data
+    raw = read_raw_fif(raw_fname, add_eeg_ref=False)
+    events = read_events(event_fname)
+
+    exclude = raw.info['bads'] + ['MEG 2443', 'EEG 053']  # bads + 2 more
+
+    # picks MEG gradiometers
+    picks = pick_types(raw.info, meg='grad', eeg=False,
+                       stim=False, include=[], exclude=exclude)
+
+    picks = picks[:2]
+    epochs = Epochs(raw, events, event_id, tmin, tmax, picks=picks,
+                    baseline=(None, 0), add_eeg_ref=False)
+    data = epochs.get_data()
+    sfreq = epochs.info['sfreq']
+    freqs = np.arange(10, 20, 3).astype(float)
+
+    # Check all combination of options
+    for method, use_fft, zero_mean, output in product(
+        ('multitaper', 'morlet'), (False, True), (False, True),
+        ('complex', 'power', 'phase',
+         'avg_power_itc', 'avg_power', 'itc')):
+        # Check exception
+        if (method == 'multitaper') and (output == 'phase'):
+            assert_raises(NotImplementedError, _compute_tfr, data, freqs,
+                          sfreq, method=method, output=output)
+            continue
+
+        # Check runs
+        out = _compute_tfr(data, freqs, sfreq, method=method,
+                           use_fft=use_fft, zero_mean=zero_mean,
+                           n_cycles=2., output=output)
+        # Check shapes
+        shape = np.r_[data.shape[:2], len(freqs), data.shape[2]]
+        if ('avg' in output) or ('itc' in output):
+            assert_array_equal(shape[1:], out.shape)
+        else:
+            assert_array_equal(shape, out.shape)
+
+        # Check types
+        if output in ('complex', 'avg_power_itc'):
+            assert_equal(np.complex, out.dtype)
+        else:
+            assert_equal(np.float, out.dtype)
+        assert_true(np.all(np.isfinite(out)))
+
+    # Check that functions are equivalent to
+    # i) single_trial_power: X, shape (n_signals, n_chans, n_times)
+    old_power = single_trial_power(data, sfreq, freqs, n_cycles=2.)
+    new_power = _compute_tfr(data, freqs, sfreq, n_cycles=2.,
+                             method='morlet', output='power')
+    assert_array_almost_equal(old_power, new_power)
+    old_power = single_trial_power(data, sfreq, freqs, n_cycles=2.,
+                                   times=epochs.times, baseline=(-.100, 0),
+                                   baseline_mode='ratio')
+    new_power = rescale(new_power, epochs.times, (-.100, 0), 'ratio')
+
+    # ii) cwt_morlet: X, shape (n_signals, n_times)
+    old_complex = cwt_morlet(data[0], sfreq, freqs, n_cycles=2.)
+    new_complex = _compute_tfr(data[[0]], freqs, sfreq, n_cycles=2.,
+                               method='morlet', output='complex')
+    assert_array_almost_equal(old_complex, new_complex[0])
+
+    # Check errors params
+    for _data in (None, 'foo', data[0]):
+        assert_raises(ValueError, _compute_tfr, _data, freqs, sfreq)
+    for _freqs in (None, 'foo', [[0]]):
+        assert_raises(ValueError, _compute_tfr, data, _freqs, sfreq)
+    for _sfreq in (None, 'foo'):
+        assert_raises(ValueError, _compute_tfr, data, freqs, _sfreq)
+    for key in ('output', 'method', 'use_fft', 'decim', 'n_jobs'):
+        for value in (None, 'foo'):
+            kwargs = {key: value}  # FIXME pep8
+            assert_raises(ValueError, _compute_tfr, data, freqs, sfreq,
+                          **kwargs)
+
+    # No time_bandwidth param in morlet
+    assert_raises(ValueError, _compute_tfr, data, freqs, sfreq,
+                  method='morlet', time_bandwidth=1)
+    # No phase in multitaper XXX Check ?
+    assert_raises(NotImplementedError, _compute_tfr, data, freqs, sfreq,
+                  method='multitaper', output='phase')
+
+    # Inter-trial coherence tests
+    out = _compute_tfr(data, freqs, sfreq, output='itc', n_cycles=2.)
+    assert_true(np.sum(out >= 1) == 0)
+    assert_true(np.sum(out <= 0) == 0)
+
+    # Check decim shapes
+    # 2: multiple of len(times) even
+    # 3: multiple odd
+    # 8: not multiple, even
+    # 9: not multiple, odd
+    for decim in (2, 3, 8, 9, slice(0, 2), slice(1, 3), slice(2, 4)):
+        _decim = slice(None, None, decim) if isinstance(decim, int) else decim
+        n_time = len(np.arange(data.shape[2])[_decim])
+        shape = np.r_[data.shape[:2], len(freqs), n_time]
+        for method in ('multitaper', 'morlet'):
+            # Single trials
+            out = _compute_tfr(data, freqs, sfreq, method=method,
+                               decim=decim, n_cycles=2.)
+            assert_array_equal(shape, out.shape)
+            # Averages
+            out = _compute_tfr(data, freqs, sfreq, method=method,
+                               decim=decim, output='avg_power',
+                               n_cycles=2.)
+            assert_array_equal(shape[1:], out.shape)
+
 run_tests_if_main()
